@@ -18,7 +18,7 @@ package static
 import (
 	"embed"
 
-	"github.com/specterops/bloodhound/src/api"
+	"github.com/specterops/bloodhound/cmd/api/src/api"
 )
 
 const (
