@@ -17,6 +17,7 @@
 package v2
 
 import (
+	"context"
 	"encoding/json"
 	"errors"
 	"fmt"
@@ -49,7 +50,8 @@ import (
 
 const (
 	assetGroupPreviewSelectorDefaultLimit = 200
-	assetGroupTagsSearchLimit             = 20
+	AssetGroupTagDefaultLimit             = 50
+	assetGroupTagQueryLimitMin            = 3
 
 	includeProperties = true
 	excludeProperties = false
@@ -383,20 +385,23 @@ func (s *Resources) GetAssetGroupTagSelector(response http.ResponseWriter, reque
 
 func (s *Resources) GetAssetGroupTagSelectors(response http.ResponseWriter, request *http.Request) {
 	var (
-		assetTagIdStr            = mux.Vars(request)[api.URIPathVariableAssetGroupTagID]
+		queryParams = request.URL.Query()
+
+		assetTagIdStr  = mux.Vars(request)[api.URIPathVariableAssetGroupTagID]
+		environmentIds = queryParams[api.QueryParameterEnvironments]
+
 		selectorQueryFilter      = make(model.QueryParameterFilterMap)
 		selectorSeedsQueryFilter = make(model.QueryParameterFilterMap)
 		selectorSeed             = model.SelectorSeed{}
 		assetGroupTagSelector    = model.AssetGroupTagSelector{}
-		queryParams              = request.URL.Query()
 	)
 
 	if skip, err := ParseSkipQueryParameter(queryParams, 0); err != nil {
 		api.WriteErrorResponse(request.Context(), ErrBadQueryParameter(request, model.PaginationQueryParameterSkip, err), response)
-	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, 99999); err != nil {
+	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, AssetGroupTagDefaultLimit); err != nil {
 		api.WriteErrorResponse(request.Context(), ErrBadQueryParameter(request, model.PaginationQueryParameterLimit, err), response)
 	} else if paramIncludeCounts, err := api.ParseOptionalBool(queryParams.Get(api.QueryParameterIncludeCounts), false); err != nil {
-		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, "Invalid value specifed for include counts", request), response)
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, "Invalid value specified for include counts", request), response)
 	} else if queryFilters, err := model.NewQueryParameterFilterParser().ParseQueryParameterFilters(request); err != nil {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsBadQueryParameterFilters, request), response)
 		return
@@ -435,9 +440,11 @@ func (s *Resources) GetAssetGroupTagSelectors(response http.ResponseWriter, requ
 			api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, "error building SQL for filter", request), response)
 		} else if selectorSeedSqlFilter, err := selectorSeedsQueryFilter.BuildSQLFilter(); err != nil {
 			api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, "error building SQL for filter", request), response)
+		} else if sort, err := api.ParseSortParameters(model.AssetGroupTagSelector{}, queryParams); err != nil {
+			api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsNotSortable, request), response)
 		} else if assetGroupTag, err := s.DB.GetAssetGroupTag(request.Context(), assetGroupTagID); err != nil {
 			api.HandleDatabaseError(request, response, err)
-		} else if selectors, count, err := s.DB.GetAssetGroupTagSelectorsByTagId(request.Context(), assetGroupTagID, selectorSqlFilter, selectorSeedSqlFilter, skip, limit); err != nil {
+		} else if selectors, count, err := s.DB.GetAssetGroupTagSelectorsByTagIdFilteredAndPaginated(request.Context(), assetGroupTagID, selectorSqlFilter, selectorSeedSqlFilter, sort, skip, limit); err != nil {
 			api.HandleDatabaseError(request, response, err)
 		} else {
 			var (
@@ -462,10 +469,18 @@ func (s *Resources) GetAssetGroupTagSelectors(response http.ResponseWriter, requ
 							}
 
 							// only count nodes that are actually tagged
-							if count, err := s.GraphQuery.CountFilteredNodes(request.Context(), query.And(
+							filters := []graph.Criteria{
 								query.KindIn(query.Node(), assetGroupTag.ToKind()),
 								query.InIDs(query.NodeID(), nodeIds...),
-							)); err != nil {
+							}
+							if len(environmentIds) > 0 {
+								filters = append(filters, query.Or(
+									query.In(query.NodeProperty(ad.DomainSID.String()), environmentIds),
+									query.In(query.NodeProperty(azure.TenantID.String()), environmentIds),
+								))
+							}
+
+							if count, err := s.GraphQuery.CountFilteredNodes(request.Context(), query.And(filters...)); err != nil {
 								api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, fmt.Sprintf("Error getting member count: %v", err), request), response)
 							} else {
 								memberCount = count
@@ -635,10 +650,10 @@ func (s *Resources) GetAssetGroupMembersByTag(response http.ResponseWriter, requ
 	} else if assetGroupTag, err := s.DB.GetAssetGroupTag(request.Context(), tagId); err != nil {
 		api.HandleDatabaseError(request, response, err)
 	} else if sort, err := api.ParseGraphSortParameters(AssetGroupMember{}, queryParams); err != nil {
-		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsColumnNotFilterable, request), response)
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsNotSortable, request), response)
 	} else if skip, err := ParseSkipQueryParameter(queryParams, 0); err != nil {
 		api.WriteErrorResponse(request.Context(), ErrBadQueryParameter(request, model.PaginationQueryParameterSkip, err), response)
-	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, 10); err != nil {
+	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, AssetGroupTagDefaultLimit); err != nil {
 		api.WriteErrorResponse(request.Context(), ErrBadQueryParameter(request, model.PaginationQueryParameterLimit, err), response)
 	} else {
 		if len(sort) == 0 {
@@ -671,8 +686,10 @@ func (s *Resources) GetAssetGroupMembersByTag(response http.ResponseWriter, requ
 
 func (s *Resources) GetAssetGroupMembersBySelector(response http.ResponseWriter, request *http.Request) {
 	var (
-		members     = []AssetGroupMember{}
-		queryParams = request.URL.Query()
+		members        = []AssetGroupMember{}
+		filter         = model.SQLFilter{}
+		queryParams    = request.URL.Query()
+		environmentIds = queryParams[api.QueryParameterEnvironments]
 	)
 
 	if assetTagId, err := strconv.Atoi(mux.Vars(request)[api.URIPathVariableAssetGroupTagID]); err != nil {
@@ -683,11 +700,11 @@ func (s *Resources) GetAssetGroupMembersBySelector(response http.ResponseWriter,
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusNotFound, api.ErrorResponseDetailsIDMalformed, request), response)
 	} else if selector, err := s.DB.GetAssetGroupTagSelectorBySelectorId(request.Context(), selectorId); err != nil {
 		api.HandleDatabaseError(request, response, err)
-	} else if sort, err := api.ParseGraphSortParameters(AssetGroupMember{}, queryParams); err != nil {
-		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsColumnNotFilterable, request), response)
+	} else if sort, err := api.ParseSortParameters(AssetGroupMember{}, queryParams); err != nil {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsNotSortable, request), response)
 	} else if skip, err := ParseSkipQueryParameter(queryParams, 0); err != nil {
 		api.WriteErrorResponse(request.Context(), ErrBadQueryParameter(request, model.PaginationQueryParameterSkip, err), response)
-	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, 10); err != nil {
+	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, AssetGroupTagDefaultLimit); err != nil {
 		api.WriteErrorResponse(request.Context(), ErrBadQueryParameter(request, model.PaginationQueryParameterLimit, err), response)
 	} else if selector.AssetGroupTagId != assetTagId {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusNotFound, "selector is not part of asset group tag", request), response)
@@ -695,67 +712,84 @@ func (s *Resources) GetAssetGroupMembersBySelector(response http.ResponseWriter,
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusConflict, "selector is disabled", request), response)
 	} else {
 		if len(sort) == 0 {
-			sort = query.SortItems{{SortCriteria: query.NodeID(), Direction: query.SortDirectionAscending}}
+			sort = model.Sort{{Column: "node_id", Direction: model.AscendingSortDirection}}
+		} else {
+			// sort items must be translated to the respective columns on the selector nodes table
+			for i, sortItem := range sort {
+				switch sortItem.Column {
+				case "id":
+					sort[i].Column = "node_id"
+				case "objectid":
+					sort[i].Column = "node_object_id"
+				case "name":
+					sort[i].Column = "node_name"
+				}
+			}
 		}
 
-		if selectorNodes, err := s.DB.GetSelectorNodesBySelectorIds(request.Context(), selectorId); err != nil {
+		if len(environmentIds) > 0 {
+			filter.SQLString = "AND node_environment_id IN ?"
+			filter.Params = append(filter.Params, environmentIds)
+		}
+
+		if selectorNodes, count, err := s.DB.GetSelectorNodesBySelectorIdsFilteredAndPaginated(request.Context(), filter, sort, skip, limit, selectorId); err != nil {
 			api.HandleDatabaseError(request, response, err)
 		} else {
-			var (
-				nodeIds        = make([]graph.ID, 0, len(selectorNodes))
-				sourceByNodeId = make(map[graph.ID]model.AssetGroupSelectorNodeSource, len(selectorNodes))
-			)
-
 			for _, node := range selectorNodes {
-				nodeIds = append(nodeIds, node.NodeId)
-				sourceByNodeId[node.NodeId] = node.Source
+				members = append(members, AssetGroupMember{
+					NodeId:          node.NodeId,
+					ObjectID:        node.NodeObjectId,
+					EnvironmentID:   node.NodeEnvironmentId,
+					PrimaryKind:     node.NodePrimaryKind,
+					Name:            node.NodeName,
+					Source:          node.Source,
+					AssetGroupTagId: assetGroupTag.ID,
+				})
 			}
 
-			filter := query.And(
-				query.KindIn(query.Node(), assetGroupTag.ToKind()),
-				query.InIDs(query.NodeID(), nodeIds...),
-			)
-
-			if nodes, err := s.GraphQuery.GetFilteredAndSortedNodesPaginated(sort, filter, skip, limit); err != nil {
-				api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, fmt.Sprintf("Error getting members: %v", err), request), response)
-			} else if count, err := s.GraphQuery.CountFilteredNodes(request.Context(), filter); err != nil {
-				api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, fmt.Sprintf("Error getting member count: %v", err), request), response)
-			} else {
-				for _, node := range nodes {
-					member := nodeToAssetGroupMember(node, false)
-					member.Source = sourceByNodeId[node.ID]
-					members = append(members, member)
-				}
-
-				api.WriteResponseWrapperWithPagination(request.Context(), GetAssetGroupMembersResponse{Members: members}, limit, skip, int(count), http.StatusOK, response)
-			}
+			api.WriteResponseWrapperWithPagination(request.Context(), GetAssetGroupMembersResponse{Members: members}, limit, skip, count, http.StatusOK, response)
 		}
 	}
 }
 
+func validateAssetGroupExpansionMethodWithFallback(maybeMethod *model.AssetGroupExpansionMethod) (model.AssetGroupExpansionMethod, error) {
+	if maybeMethod == nil {
+		return model.AssetGroupExpansionMethodAll, nil
+	}
+	switch *maybeMethod {
+	case model.AssetGroupExpansionMethodNone, model.AssetGroupExpansionMethodAll, model.AssetGroupExpansionMethodChildren, model.AssetGroupExpansionMethodParents:
+		return *maybeMethod, nil
+	default:
+		return 0, fmt.Errorf("invalid expansion method")
+	}
+}
+
 type PreviewSelectorBody struct {
-	Seeds model.SelectorSeeds `json:"seeds" validate:"required"`
+	Seeds     model.SelectorSeeds              `json:"seeds" validate:"required"`
+	Expansion *model.AssetGroupExpansionMethod `json:"expansion"`
 }
 
 func (s *Resources) PreviewSelectors(response http.ResponseWriter, request *http.Request) {
 	var (
-		seeds   PreviewSelectorBody
+		body    PreviewSelectorBody
 		members = []AssetGroupMember{}
 	)
 
 	if limit, err := ParseLimitQueryParameter(request.URL.Query(), assetGroupPreviewSelectorDefaultLimit); err != nil {
 		api.WriteErrorResponse(request.Context(), ErrBadQueryParameter(request, model.PaginationQueryParameterLimit, err), response)
-	} else if err := json.NewDecoder(request.Body).Decode(&seeds); err != nil {
+	} else if err := json.NewDecoder(request.Body).Decode(&body); err != nil {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponsePayloadUnmarshalError, request), response)
-	} else if errs := validation.Validate(seeds); len(errs) > 0 {
+	} else if errs := validation.Validate(body); len(errs) > 0 {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, errs.Error(), request), response)
 	} else if _, isUser := auth.GetUserFromAuthCtx(ctx.FromRequest(request).AuthCtx); !isUser {
 		slog.Error("Unable to get user from auth context")
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, "unknown user", request), response)
-	} else if err := validateSelectorSeeds(s.GraphQuery, seeds.Seeds); err != nil {
+	} else if err := validateSelectorSeeds(s.GraphQuery, body.Seeds); err != nil {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, err.Error(), request), response)
+	} else if expansion, err := validateAssetGroupExpansionMethodWithFallback(body.Expansion); err != nil {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, err.Error(), request), response)
 	} else {
-		nodes := datapipe.FetchNodesFromSeeds(request.Context(), s.Graph, seeds.Seeds, model.AssetGroupExpansionMethodAll, limit)
+		nodes := datapipe.FetchNodesFromSeeds(request.Context(), s.Graph, body.Seeds, expansion, limit)
 		for _, node := range nodes {
 			if node.Node != nil {
 				members = append(members, nodeToAssetGroupMember(node.Node, excludeProperties))
@@ -798,7 +832,7 @@ func (s *Resources) SearchAssetGroupTags(response http.ResponseWriter, request *
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponsePayloadUnmarshalError, request), response)
 	} else if !validateAssetGroupTagType(reqBody.TagType) {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseAssetGroupTagInvalid, request), response)
-	} else if len(reqBody.Query) < 3 {
+	} else if len(reqBody.Query) < assetGroupTagQueryLimitMin {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsQueryTooShort, request), response)
 	} else if tags, err := s.DB.GetAssetGroupTags(request.Context(), model.SQLFilter{}); err != nil && !errors.Is(err, database.ErrNotFound) {
 		api.HandleDatabaseError(request, response, err)
@@ -817,7 +851,7 @@ func (s *Resources) SearchAssetGroupTags(response http.ResponseWriter, request *
 				kinds = kinds.Add(t.ToKind())
 				tagIds = append(tagIds, t.ID)
 				tagIdByKind[t.ToKind()] = t.ID
-				if strings.Contains(strings.ToLower(t.Name), strings.ToLower(reqBody.Query)) && len(matchedTags) < assetGroupTagsSearchLimit {
+				if strings.Contains(strings.ToLower(t.Name), strings.ToLower(reqBody.Query)) && len(matchedTags) < AssetGroupTagDefaultLimit {
 					matchedTags = append(matchedTags, t)
 				}
 			}
@@ -833,10 +867,10 @@ func (s *Resources) SearchAssetGroupTags(response http.ResponseWriter, request *
 			selectorFilter = model.SQLFilter{SQLString: "name ILIKE ? AND asset_group_tag_id IN ?", Params: []any{"%" + reqBody.Query + "%", tagIds}}
 		)
 
-		if selectors, err = s.DB.GetAssetGroupTagSelectors(request.Context(), selectorFilter, assetGroupTagsSearchLimit); err != nil && !errors.Is(err, database.ErrNotFound) {
+		if selectors, err = s.DB.GetAssetGroupTagSelectors(request.Context(), selectorFilter, AssetGroupTagDefaultLimit); err != nil && !errors.Is(err, database.ErrNotFound) {
 			api.HandleDatabaseError(request, response, err)
 			return
-		} else if nodes, err := s.GraphQuery.GetFilteredAndSortedNodesPaginated(query.SortItems{{SortCriteria: query.NodeProperty(common.Name.String()), Direction: query.SortDirectionAscending}}, nodeFilter, 0, assetGroupTagsSearchLimit); err != nil {
+		} else if nodes, err := s.GraphQuery.GetFilteredAndSortedNodesPaginated(query.SortItems{{SortCriteria: query.NodeProperty(common.Name.String()), Direction: query.SortDirectionAscending}}, nodeFilter, 0, AssetGroupTagDefaultLimit); err != nil {
 			api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, fmt.Sprintf("Error getting members: %v", err), request), response)
 			return
 		} else {
@@ -861,22 +895,21 @@ type AssetGroupHistoryResp struct {
 	Records []model.AssetGroupHistory `json:"records"`
 }
 
-func (s *Resources) GetAssetGroupTagHistory(response http.ResponseWriter, request *http.Request) {
+func (s *Resources) assetGroupTagHistoryImplementation(response http.ResponseWriter, request *http.Request, query string) {
 	var (
 		rCtx        = request.Context()
 		queryParams = request.URL.Query()
+		sort        model.Sort
+		sqlFilter   model.SQLFilter
 	)
 
-	defer measure.ContextMeasure(rCtx, slog.LevelDebug, "Asset Group Tag Get History Records")()
-
 	if queryFilters, err := model.NewQueryParameterFilterParser().ParseQueryParameterFilters(request); err != nil {
 		api.WriteErrorResponse(rCtx, api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsBadQueryParameterFilters, request), response)
-		return
 	} else if skip, err := ParseSkipQueryParameter(queryParams, 0); err != nil {
 		api.WriteErrorResponse(rCtx, ErrBadQueryParameter(request, model.PaginationQueryParameterSkip, err), response)
-	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, 100); err != nil {
+	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, AssetGroupTagDefaultLimit); err != nil {
 		api.WriteErrorResponse(rCtx, ErrBadQueryParameter(request, model.PaginationQueryParameterLimit, err), response)
-	} else if sort, err := api.ParseSortParameters(model.AssetGroupHistory{}, queryParams); err != nil {
+	} else if sort, err = api.ParseSortParameters(model.AssetGroupHistory{}, queryParams); err != nil {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsNotSortable, request), response)
 	} else {
 		for name, filters := range queryFilters {
@@ -898,12 +931,254 @@ func (s *Resources) GetAssetGroupTagHistory(response http.ResponseWriter, reques
 			sort = model.Sort{{Column: "created_at", Direction: model.DescendingSortDirection}}
 		}
 
-		if sqlFilter, err := queryFilters.BuildSQLFilter(); err != nil {
+		if sqlFilter, err = queryFilters.BuildSQLFilter(); err != nil {
 			api.WriteErrorResponse(rCtx, api.BuildErrorResponse(http.StatusBadRequest, "error building SQL for filter", request), response)
-		} else if historyRecs, count, err := s.DB.GetAssetGroupHistoryRecords(rCtx, sqlFilter, sort, skip, limit); err != nil && !errors.Is(err, database.ErrNotFound) {
+			return
+		}
+
+		if query != "" {
+			querySQL := "(actor ILIKE ? OR email ILIKE ? OR action ILIKE ? OR target ILIKE ?)"
+
+			if sqlFilter.SQLString != "" {
+				querySQL = " AND" + querySQL
+			}
+
+			sqlFilter.SQLString += querySQL
+
+			for range 4 {
+				sqlFilter.Params = append(sqlFilter.Params, "%"+query+"%")
+			}
+		}
+
+		if historyRecs, count, err := s.DB.GetAssetGroupHistoryRecords(rCtx, sqlFilter, sort, skip, limit); err != nil && !errors.Is(err, database.ErrNotFound) {
 			api.HandleDatabaseError(request, response, err)
 		} else {
 			api.WriteResponseWrapperWithPagination(rCtx, AssetGroupHistoryResp{Records: historyRecs}, limit, skip, count, http.StatusOK, response)
 		}
 	}
 }
+
+type SearchAssetGroupTagHistoryRequest struct {
+	Query string `json:"query"`
+}
+
+func (s *Resources) SearchAssetGroupTagHistory(response http.ResponseWriter, request *http.Request) {
+	reqBody := SearchAssetGroupTagHistoryRequest{}
+
+	defer measure.ContextMeasure(request.Context(), slog.LevelDebug, "Asset Group Tag Search History Records")()
+
+	if err := json.NewDecoder(request.Body).Decode(&reqBody); err != nil {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponsePayloadUnmarshalError, request), response)
+	} else if len(reqBody.Query) < assetGroupTagQueryLimitMin {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsQueryTooShort, request), response)
+	} else {
+		s.assetGroupTagHistoryImplementation(response, request, reqBody.Query)
+	}
+}
+
+func (s *Resources) GetAssetGroupTagHistory(response http.ResponseWriter, request *http.Request) {
+	defer measure.ContextMeasure(request.Context(), slog.LevelDebug, "Asset Group Tag Get History Records")()
+
+	s.assetGroupTagHistoryImplementation(response, request, "")
+}
+
+type CertifyMembersRequest struct {
+	MemberIDs []int                         `json:"member_ids"`
+	Action    model.AssetGroupCertification `json:"action"`
+	Note      string                        `json:"note,omitempty"`
+}
+
+func isValidCertType(certType model.AssetGroupCertification) bool {
+	switch certType {
+	case model.AssetGroupCertificationManual, model.AssetGroupCertificationRevoked:
+		return true
+	default:
+		return false
+	}
+}
+
+func recordEligibleForUpdate(record model.AssetGroupSelectorNodeExpanded, lastProcessedNodeId graph.ID, highestPriority int) bool {
+	if record.NodeId != lastProcessedNodeId {
+		return true
+	} else if record.Position == highestPriority {
+		return true
+	}
+	return false
+}
+
+type setSelectorNodeCertifier interface {
+	UpdateCertificationBySelectorNode(ctx context.Context, input []database.UpdateCertificationBySelectorNodeInput) error
+}
+
+// certifyMembersBySelectorNodes updates the certification status for a given slice of selectorNodeRecords.
+// selectorNodeRecords supplied must be in order of nodeId, followed by position.
+// If there are duplicate nodeIds in selectorNodeRecords, only the lowest position (highest priority) selectorNodeRecords is updated,
+// and all lower-priority selectorNodeRecords are set to Pending Certification.
+func certifyMembersBySelectorNodes(ctx context.Context, selectorNodeCertifier setSelectorNodeCertifier, selectorNodeRecords []model.AssetGroupSelectorNodeExpanded, requestAction model.AssetGroupCertification, userEmail null.String, userId string, note null.String) error {
+	var (
+		certificationStatus model.AssetGroupCertification
+		certifiedBy         null.String
+
+		lastProcessedNodeId         graph.ID = 0
+		highestPriorityForGivenNode          = -1
+
+		inputs = []database.UpdateCertificationBySelectorNodeInput{}
+	)
+
+	// Only update the records with the highest priority for a given nodeID
+	for _, record := range selectorNodeRecords {
+		certificationStatus = model.AssetGroupCertificationPending
+		certifiedBy = null.String{}
+		if recordEligibleForUpdate(record, lastProcessedNodeId, highestPriorityForGivenNode) {
+			certificationStatus = requestAction
+			highestPriorityForGivenNode = record.Position
+			certifiedBy = userEmail
+			lastProcessedNodeId = record.NodeId
+			// don't actually update records that already match the request action or are auto-certified
+			if record.Certified == requestAction || record.Certified == model.AssetGroupCertificationAuto {
+				continue
+			}
+		}
+		inputs = append(inputs, database.UpdateCertificationBySelectorNodeInput{AssetGroupTagId: record.AssetGroupTagId, SelectorId: record.SelectorId, CertifiedBy: certifiedBy, UserId: userId, CertificationStatus: certificationStatus, NodeId: record.NodeId, NodeName: record.NodeName, Note: note})
+		lastProcessedNodeId = record.NodeId
+	}
+	if len(inputs) > 0 {
+		return selectorNodeCertifier.UpdateCertificationBySelectorNode(ctx, inputs)
+	}
+	return nil
+}
+
+func (s *Resources) CertifyMembers(response http.ResponseWriter, request *http.Request) {
+	var (
+		reqBody    CertifyMembersRequest
+		requestCtx = request.Context()
+	)
+	defer measure.ContextMeasure(requestCtx, slog.LevelDebug, "Asset Group Tag Certify Members")()
+	if err := json.NewDecoder(request.Body).Decode(&reqBody); err != nil {
+		api.WriteErrorResponse(requestCtx, api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponsePayloadUnmarshalError, request), response)
+	} else if user, isUser := auth.GetUserFromAuthCtx(ctx.FromRequest(request).AuthCtx); !isUser {
+		slog.Error("Unable to get user from auth context")
+		api.WriteErrorResponse(requestCtx, api.BuildErrorResponse(http.StatusInternalServerError, api.ErrorResponseUnknownUser, request), response)
+	} else if !isValidCertType(reqBody.Action) {
+		api.WriteErrorResponse(requestCtx, api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseAssetGroupCertTypeInvalid, request), response)
+	} else if memberIds := reqBody.MemberIDs; len(memberIds) == 0 {
+		api.WriteErrorResponse(requestCtx, api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseAssetGroupMemberIDsRequired, request), response)
+	} else if nodes, err := s.DB.GetAssetGroupSelectorNodeExpandedOrderedByIdAndPosition(requestCtx, reqBody.MemberIDs...); err != nil {
+		api.HandleDatabaseError(request, response, err)
+	} else if err := certifyMembersBySelectorNodes(requestCtx, s.DB, nodes, reqBody.Action, user.EmailAddress, user.ID.String(), null.StringFrom(reqBody.Note)); err != nil {
+		api.HandleDatabaseError(request, response, err)
+	} else {
+		response.WriteHeader(http.StatusOK)
+	}
+}
+
+type AssetGroupMemberWithCertification struct {
+	AssetGroupMember
+	CreatedAt   time.Time                     `json:"created_at"`
+	CertifiedBy string                        `json:"certified_by"`
+	Certified   model.AssetGroupCertification `json:"certified"`
+}
+
+// note some of these filters do not match the db column names and require translation to work
+func (AssetGroupMemberWithCertification) ValidFilters() map[string][]model.FilterOperator {
+	return map[string][]model.FilterOperator{
+		"asset_group_tag_id": {model.Equals, model.GreaterThan, model.GreaterThanOrEquals, model.LessThan, model.LessThanOrEquals, model.NotEquals},
+		"certified":          {model.Equals, model.GreaterThan, model.GreaterThanOrEquals, model.LessThan, model.LessThanOrEquals, model.NotEquals},
+		"certified_by":       {model.Equals, model.NotEquals, model.ApproximatelyEquals},
+		"created_at":         {model.Equals, model.GreaterThan, model.GreaterThanOrEquals, model.LessThan, model.LessThanOrEquals, model.NotEquals},
+		"environments":       {model.Equals, model.NotEquals, model.ApproximatelyEquals},
+		"name":               {model.Equals, model.NotEquals, model.ApproximatelyEquals},
+		"object_id":          {model.Equals, model.NotEquals, model.ApproximatelyEquals},
+		"primary_kind":       {model.Equals, model.NotEquals, model.ApproximatelyEquals},
+	}
+}
+
+func (AssetGroupMemberWithCertification) IsStringColumn(filter string) bool {
+	switch filter {
+	case "environments",
+		"primary_kind",
+		"certified_by",
+		"name",
+		"object_id":
+		return true
+	default:
+		return false
+	}
+}
+
+type GetAssetGroupMembersWithCertificationResponse struct {
+	Members []AssetGroupMemberWithCertification `json:"members"`
+}
+
+func (s *Resources) GetAssetGroupTagCertifications(response http.ResponseWriter, request *http.Request) {
+	var (
+		requestContext                    = request.Context()
+		defaultSkip                       = 0
+		defaultLimit                      = AssetGroupTagDefaultLimit
+		assetGroupMemberWithCertification = AssetGroupMemberWithCertification{}
+		queryParams                       = request.URL.Query()
+		translatedQueryFilter             = make(model.QueryParameterFilterMap)
+	)
+	// Parse Query Parameters
+	if skip, err := ParseSkipQueryParameter(queryParams, defaultSkip); err != nil {
+		api.WriteErrorResponse(requestContext, ErrBadQueryParameter(request, model.PaginationQueryParameterSkip, err), response)
+	} else if limit, err := ParseOptionalLimitQueryParameter(queryParams, defaultLimit); err != nil {
+		api.WriteErrorResponse(requestContext, ErrBadQueryParameter(request, model.PaginationQueryParameterLimit, err), response)
+	} else if queryFilters, err := model.NewQueryParameterFilterParser().ParseQueryParameterFilters(request); err != nil {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsBadQueryParameterFilters, request), response)
+	} else {
+		for name, filters := range queryFilters {
+			if validPredicates, err := api.GetValidFilterPredicatesAsStrings(assetGroupMemberWithCertification, name); err != nil {
+				api.WriteErrorResponse(requestContext, api.BuildErrorResponse(http.StatusBadRequest, fmt.Sprintf("%s: %s", api.ErrorResponseDetailsColumnNotFilterable, name), request), response)
+				return
+			} else {
+				for i, filter := range filters {
+					if !slices.Contains(validPredicates, string(filter.Operator)) {
+						api.WriteErrorResponse(requestContext, api.BuildErrorResponse(http.StatusBadRequest, fmt.Sprintf("%s: %s %s", api.ErrorResponseDetailsFilterPredicateNotSupported, filter.Name, filter.Operator), request), response)
+						return
+					}
+
+					// some of the API filter names do not match the DB column names - so we have to do a translation here
+					originalName := filter.Name
+					switch filter.Name {
+					case "environments":
+						filter.Name = "node_environment_id"
+					case "name":
+						filter.Name = "node_name"
+					case "object_id":
+						filter.Name = "node_object_id"
+					case "primary_kind":
+						filter.Name = "node_primary_kind"
+					}
+					translatedQueryFilter.AddFilter(filter)
+					translatedQueryFilter[filter.Name][i].IsStringData = assetGroupMemberWithCertification.IsStringColumn(originalName)
+				}
+			}
+		}
+
+		if sqlFilter, err := translatedQueryFilter.BuildSQLFilter(); err != nil {
+			api.WriteErrorResponse(requestContext, api.BuildErrorResponse(http.StatusBadRequest, "error building SQL for filter", request), response)
+		} else if selectorNodes, count, err := s.DB.GetAggregatedSelectorNodesCertification(requestContext, sqlFilter, skip, limit); err != nil {
+			api.HandleDatabaseError(request, response, err)
+		} else {
+			// return paginated AssetGroupMemberWithCertification of matches and also a count
+			members := make([]AssetGroupMemberWithCertification, len(selectorNodes))
+			for i, selNode := range selectorNodes {
+				members[i] = AssetGroupMemberWithCertification{
+					AssetGroupMember: AssetGroupMember{
+						NodeId:          selNode.NodeId,
+						ObjectID:        selNode.NodeObjectId,
+						EnvironmentID:   selNode.NodeEnvironmentId,
+						PrimaryKind:     selNode.NodePrimaryKind,
+						Name:            selNode.NodeName,
+						AssetGroupTagId: selNode.AssetGroupTagId,
+					},
+					CreatedAt:   selNode.CreatedAt,
+					CertifiedBy: selNode.CertifiedBy.ValueOrZero(),
+					Certified:   selNode.Certified,
+				}
+			}
+			api.WriteResponseWrapperWithPagination(request.Context(), GetAssetGroupMembersWithCertificationResponse{Members: members}, limit, skip, count, http.StatusOK, response)
+		}
+	}
+}
