@@ -134,36 +134,38 @@ type DefaultAdminConfiguration struct {
 }
 
 type Configuration struct {
-	Version                      int                       `json:"version"`
-	BindAddress                  string                    `json:"bind_addr"`
-	SlowQueryThreshold           int64                     `json:"slow_query_threshold"`
-	MaxGraphQueryCacheSize       int                       `json:"max_graphdb_cache_size"`
-	MaxAPICacheSize              int                       `json:"max_api_cache_size"`
-	MetricsPort                  string                    `json:"metrics_port"`
-	RootURL                      serde.URL                 `json:"root_url"`
-	WorkDir                      string                    `json:"work_dir"`
-	LogLevel                     string                    `json:"log_level"`
-	LogPath                      string                    `json:"log_path"`
-	TLS                          TLSConfiguration          `json:"tls"`
-	GraphDriver                  string                    `json:"graph_driver"`
-	Database                     DatabaseConfiguration     `json:"database"`
-	Neo4J                        DatabaseConfiguration     `json:"neo4j"`
-	Crypto                       CryptoConfiguration       `json:"crypto"`
-	SAML                         SAMLConfiguration         `json:"saml"`
-	DefaultAdmin                 DefaultAdminConfiguration `json:"default_admin"`
-	CollectorsBucketURL          serde.URL                 `json:"collectors_bucket_url"`
-	CollectorsBasePath           string                    `json:"collectors_base_path"`
-	DatapipeInterval             int                       `json:"datapipe_interval"`
-	EnableStartupWaitPeriod      bool                      `json:"enable_startup_wait_period"`
-	EnableAPILogging             bool                      `json:"enable_api_logging"`
-	EnableCypherMutations        bool                      `json:"enable_cypher_mutations"`
-	DisableAnalysis              bool                      `json:"disable_analysis"`
-	DisableCypherComplexityLimit bool                      `json:"disable_cypher_complexity_limit"`
-	DisableIngest                bool                      `json:"disable_ingest"`
-	DisableMigrations            bool                      `json:"disable_migrations"`
-	GraphQueryMemoryLimit        uint16                    `json:"graph_query_memory_limit"`
-	EnableTextLogger             bool                      `json:"enable_text_logger"`
-	RecreateDefaultAdmin         bool                      `json:"recreate_default_admin"`
+	Version                         int                       `json:"version"`
+	BindAddress                     string                    `json:"bind_addr"`
+	SlowQueryThreshold              int64                     `json:"slow_query_threshold"`
+	MaxGraphQueryCacheSize          int                       `json:"max_graphdb_cache_size"`
+	MaxAPICacheSize                 int                       `json:"max_api_cache_size"`
+	MetricsPort                     string                    `json:"metrics_port"`
+	RootURL                         serde.URL                 `json:"root_url"`
+	WorkDir                         string                    `json:"work_dir"`
+	LogLevel                        string                    `json:"log_level"`
+	LogPath                         string                    `json:"log_path"`
+	TLS                             TLSConfiguration          `json:"tls"`
+	GraphDriver                     string                    `json:"graph_driver"`
+	Database                        DatabaseConfiguration     `json:"database"`
+	Neo4J                           DatabaseConfiguration     `json:"neo4j"`
+	Crypto                          CryptoConfiguration       `json:"crypto"`
+	SAML                            SAMLConfiguration         `json:"saml"`
+	DefaultAdmin                    DefaultAdminConfiguration `json:"default_admin"`
+	CollectorsBucketURL             serde.URL                 `json:"collectors_bucket_url"`
+	CollectorsBasePath              string                    `json:"collectors_base_path"`
+	DatapipeInterval                int                       `json:"datapipe_interval"`
+	EnableStartupWaitPeriod         bool                      `json:"enable_startup_wait_period"`
+	EnableAPILogging                bool                      `json:"enable_api_logging"`
+	EnableCypherMutations           bool                      `json:"enable_cypher_mutations"`
+	DisableAnalysis                 bool                      `json:"disable_analysis"`
+	DisableCypherComplexityLimit    bool                      `json:"disable_cypher_complexity_limit"`
+	DisableIngest                   bool                      `json:"disable_ingest"`
+	DisableMigrations               bool                      `json:"disable_migrations"`
+	GraphQueryMemoryLimit           uint16                    `json:"graph_query_memory_limit"`
+	EnableTextLogger                bool                      `json:"enable_text_logger"`
+	RecreateDefaultAdmin            bool                      `json:"recreate_default_admin"`
+	EnableUserAnalytics             bool                      `json:"enable_user_analytics"`
+	ForceDownloadEmbeddedCollectors bool                      `json:"force_download_embedded_collectors"`
 }
 
 func (s Configuration) TempDirectory() string {
@@ -279,16 +281,21 @@ func GetConfiguration(path string, defaultConfigFunc func() (Configuration, erro
 	}
 }
 
-func GetTextLoggerEnabled() (bool, error) {
-	if enableTextLogger := os.Getenv(BHAPIEnvironmentVariablePrefix + "_enable_text_logger"); enableTextLogger == "" {
-		return false, nil
-	} else if enabled, err := strconv.ParseBool(enableTextLogger); err != nil {
-		return false, fmt.Errorf("failed to parse %s to bool: %v", BHAPIEnvironmentVariablePrefix+"_enable_text_logger", err)
-	} else if enabled {
-		return true, nil
-	}
+func GetTextLoggerEnabled() bool {
+	const env = BHAPIEnvironmentVariablePrefix + "_enable_text_logger"
 
-	return false, nil
+	if enableTextLogger := os.Getenv(env); enableTextLogger == "" {
+		return false
+	} else if enabled, err := strconv.ParseBool(enableTextLogger); err != nil {
+		slog.Warn(
+			"Failed to parse text logger environment variable",
+			slog.String("env_key", env),
+			slog.String("err", err.Error()),
+		)
+		return false
+	} else {
+		return enabled
+	}
 }
 
 const (
