@@ -23,6 +23,7 @@ import (
 	"log/slog"
 
 	"github.com/specterops/bloodhound/cmd/api/src/config"
+	"github.com/specterops/bloodhound/cmd/api/src/daemons/changelog"
 	"github.com/specterops/bloodhound/cmd/api/src/database"
 	"github.com/specterops/bloodhound/cmd/api/src/model"
 	"github.com/specterops/bloodhound/cmd/api/src/model/appcfg"
@@ -47,9 +48,10 @@ type BHCEPipeline struct {
 	ingestSchema        upload.IngestSchema
 	jobService          job.JobService
 	graphifyService     graphify.GraphifyService
+	changelog           *changelog.Changelog
 }
 
-func NewPipeline(ctx context.Context, cfg config.Configuration, db database.Database, graphDB graph.Database, cache cache.Cache, ingestSchema upload.IngestSchema) *BHCEPipeline {
+func NewPipeline(ctx context.Context, cfg config.Configuration, db database.Database, graphDB graph.Database, cache cache.Cache, ingestSchema upload.IngestSchema, cl *changelog.Changelog) *BHCEPipeline {
 	return &BHCEPipeline{
 		db:                  db,
 		graphdb:             graphDB,
@@ -58,7 +60,8 @@ func NewPipeline(ctx context.Context, cfg config.Configuration, db database.Data
 		orphanedFileSweeper: NewOrphanFileSweeper(NewOSFileOperations(), cfg.TempDirectory()),
 		ingestSchema:        ingestSchema,
 		jobService:          job.NewJobService(ctx, db),
-		graphifyService:     graphify.NewGraphifyService(ctx, db, graphDB, cfg, ingestSchema),
+		graphifyService:     graphify.NewGraphifyService(ctx, db, graphDB, cfg, ingestSchema, cl),
+		changelog:           cl,
 	}
 }
 
@@ -88,6 +91,11 @@ func (s *BHCEPipeline) DeleteData(ctx context.Context) error {
 		return fmt.Errorf("purging graph data failed: %w", err)
 	}
 
+	// Clear changelog cache to ensure consistency after graph data deletion
+	if s.changelog != nil {
+		s.changelog.ClearCache(ctx)
+	}
+
 	return nil
 }
 
@@ -178,6 +186,7 @@ func updateJobFunc(ctx context.Context, db database.Database) graphify.UpdateJob
 			for _, file := range fileData {
 				job.TotalFiles += 1
 				completedTask := model.CompletedTask{
+					IngestJobId:    job.ID,
 					FileName:       file.Name,
 					ParentFileName: file.ParentFile,
 					Errors:         []string{},
