@@ -22,7 +22,9 @@ import (
 	"context"
 	"fmt"
 	"log"
+	"sort"
 	"strconv"
+	"strings"
 	"testing"
 	"time"
 
@@ -306,7 +308,7 @@ func TestDatabase_CreateAssetGroupTag(t *testing.T) {
 		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[2].Action)
 	})
 
-	t.Run("Non existant tag errors out", func(t *testing.T) {
+	t.Run("Non existent tag errors out", func(t *testing.T) {
 		dbInst := integration.SetupDB(t)
 
 		_, err := dbInst.GetAssetGroupTag(testCtx, 1234)
@@ -721,7 +723,7 @@ func TestDatabase_DeleteAssetGroupTag(t *testing.T) {
 		require.Equal(t, model.AssetGroupHistoryActionDeleteTag, history[1].Action)
 	})
 
-	t.Run("Non existant asset group tag errors out", func(t *testing.T) {
+	t.Run("Non existent asset group tag errors out", func(t *testing.T) {
 		dbInst := integration.SetupDB(t)
 
 		_, err := dbInst.GetAssetGroupTag(testCtx, 1234)
@@ -872,7 +874,7 @@ func TestDatabase_GetAssetGroupTagSelectorCounts(t *testing.T) {
 	})
 }
 
-func TestDatabase_GetAssetGroupTagSelectorsBySelectorId(t *testing.T) {
+func TestDatabase_GetAssetGroupTagSelectorsBySelectorIdFilteredAndPaginated(t *testing.T) {
 	var (
 		dbInst        = integration.SetupDB(t)
 		testCtx       = context.Background()
@@ -909,7 +911,7 @@ func TestDatabase_GetAssetGroupTagSelectorsBySelectorId(t *testing.T) {
 	require.NoError(t, err)
 
 	t.Run("successfully returns an array of selectors, no filters", func(t *testing.T) {
-		orig_results, _, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{}, model.SQLFilter{}, 0, 0)
+		orig_results, _, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1)
 		require.NoError(t, err)
 
 		results := make(model.AssetGroupTagSelectors, 0, 2)
@@ -919,7 +921,7 @@ func TestDatabase_GetAssetGroupTagSelectorsBySelectorId(t *testing.T) {
 			}
 		}
 
-		require.Equal(t, 2, len(results))
+		require.Len(t, results, 2)
 		require.Equal(t, test1Selector.Name, results[0].Name)
 		require.Equal(t, test2Selector.Name, results[1].Name)
 		require.Equal(t, test1Selector.Description, results[0].Description)
@@ -946,7 +948,7 @@ func TestDatabase_GetAssetGroupTagSelectorsBySelectorId(t *testing.T) {
 	})
 
 	t.Run("successfully returns an array of seed selector filters", func(t *testing.T) {
-		orig_results, _, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{}, model.SQLFilter{SQLString: "type = 2"}, 0, 0)
+		orig_results, _, err := dbInst.GetAssetGroupTagSelectorsByTagIdFilteredAndPaginated(testCtx, 1, model.SQLFilter{}, model.SQLFilter{SQLString: "type = 2"}, model.Sort{}, 0, 0)
 		require.NoError(t, err)
 
 		results := make(model.AssetGroupTagSelectors, 0, 1)
@@ -956,7 +958,7 @@ func TestDatabase_GetAssetGroupTagSelectorsBySelectorId(t *testing.T) {
 			}
 		}
 
-		require.Equal(t, 1, len(results))
+		require.Len(t, results, 1)
 		for idx, seed := range test2Selector.Seeds {
 			require.Equal(t, seed.Type, results[0].Seeds[idx].Type)
 			require.Equal(t, seed.Value, results[0].Seeds[idx].Value)
@@ -964,28 +966,38 @@ func TestDatabase_GetAssetGroupTagSelectorsBySelectorId(t *testing.T) {
 	})
 
 	t.Run("successfully returns an array of selector filters", func(t *testing.T) {
-		results, _, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{created_at}}, model.SQLFilter{}, 0, 0)
+		results, _, err := dbInst.GetAssetGroupTagSelectorsByTagIdFilteredAndPaginated(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{created_at}}, model.SQLFilter{}, model.Sort{}, 0, 0)
 		require.NoError(t, err)
 
-		require.Equal(t, 1, len(results))
+		require.Len(t, results, 1)
 		require.True(t, results[0].CreatedAt.After(created_at))
 
 	})
 
 	t.Run("successfully returns an array using the skip param", func(t *testing.T) {
-		results, count, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{test_started_at}}, model.SQLFilter{}, 1, 0)
+		results, count, err := dbInst.GetAssetGroupTagSelectorsByTagIdFilteredAndPaginated(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{test_started_at}}, model.SQLFilter{}, model.Sort{}, 1, 0)
 		require.NoError(t, err)
 
-		require.Equal(t, 1, len(results))
+		require.Len(t, results, 1)
 		require.Equal(t, 2, count)
 		require.Equal(t, test2Selector.Name, results[0].Name)
 	})
 
-	t.Run("successfully returns an array using the limit param", func(t *testing.T) {
-		results, count, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{test_started_at}}, model.SQLFilter{}, 0, 1)
+	t.Run("successfully returns an array sorted by name desc", func(t *testing.T) {
+		results, _, err := dbInst.GetAssetGroupTagSelectorsByTagIdFilteredAndPaginated(testCtx, 1, model.SQLFilter{}, model.SQLFilter{}, model.Sort{{Direction: model.DescendingSortDirection, Column: "name"}}, 0, 0)
 		require.NoError(t, err)
 
-		require.Equal(t, 1, len(results))
+		require.Greater(t, len(results), 1)
+		require.True(t, sort.SliceIsSorted(results, func(i, j int) bool {
+			return strings.ReplaceAll(strings.ToLower(results[i].Name), " ", "") > strings.ReplaceAll(strings.ToLower(results[j].Name), " ", "")
+		}))
+	})
+
+	t.Run("successfully returns an array using the limit param", func(t *testing.T) {
+		results, count, err := dbInst.GetAssetGroupTagSelectorsByTagIdFilteredAndPaginated(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{test_started_at}}, model.SQLFilter{}, model.Sort{}, 0, 1)
+		require.NoError(t, err)
+
+		require.Len(t, results, 1)
 		require.Equal(t, 2, count)
 		require.Equal(t, test1Selector.Name, results[0].Name)
 	})
@@ -1127,3 +1139,401 @@ func TestDatabase_GetAssetGroupTagSelectors(t *testing.T) {
 		require.GreaterOrEqual(t, len(items), 2)
 	})
 }
+
+func TestDatabase_UpdateCertificationBySelectorNode(t *testing.T) {
+	t.Parallel()
+	suite := setupIntegrationTestSuite(t)
+	defer teardownIntegrationTestSuite(t, &suite)
+
+	var (
+		testCtx              = context.Background()
+		testNote             = null.StringFrom("test")
+		testAssetGroupTagId1 = 1
+		testSelectorId1      = 1
+		testSelectorId2      = 2
+		testMemberId1        = 1
+		testNodeId1          = graph.ID(uint64(testMemberId1))
+		testMemberId2        = 2
+		testNodeId2          = graph.ID(uint64(testMemberId2))
+		certifiedBy          = null.StringFrom("testy")
+		source               = 1
+		isDefault            = false
+		allowDisable         = true
+		autoCertify          = null.BoolFrom(false)
+		test1Selector        = model.AssetGroupTagSelector{
+			Name:        "test selector name",
+			Description: "test description",
+			Seeds: []model.SelectorSeed{
+				{Type: model.SelectorTypeObjectId, Value: "ObjectID1234"},
+			},
+		}
+		updateInputCertify = database.UpdateCertificationBySelectorNodeInput{AssetGroupTagId: testAssetGroupTagId1, SelectorId: testSelectorId1, CertifiedBy: certifiedBy, CertificationStatus: model.AssetGroupCertificationManual, NodeId: testNodeId1, NodeName: test1Selector.Name, Note: testNote}
+		updateInputPending = database.UpdateCertificationBySelectorNodeInput{AssetGroupTagId: testAssetGroupTagId1, SelectorId: testSelectorId2, CertifiedBy: certifiedBy, CertificationStatus: model.AssetGroupCertificationPending, NodeId: testNodeId1, NodeName: test1Selector.Name, Note: testNote}
+		updateInputNode2   = database.UpdateCertificationBySelectorNodeInput{AssetGroupTagId: testAssetGroupTagId1, SelectorId: testSelectorId1, CertifiedBy: certifiedBy, CertificationStatus: model.AssetGroupCertificationManual, NodeId: testNodeId2, NodeName: test1Selector.Name, Note: testNote}
+		sort               = make(model.Sort, 0)
+	)
+	_, err := suite.BHDatabase.CreateAssetGroupTagSelector(testCtx, testAssetGroupTagId1, model.User{}, test1Selector.Name, test1Selector.Description, isDefault, allowDisable, autoCertify, test1Selector.Seeds)
+	require.NoError(t, err)
+
+	// insert selector nodes
+	err = suite.BHDatabase.InsertSelectorNode(testCtx, testAssetGroupTagId1, testSelectorId1, testNodeId1, model.AssetGroupCertificationRevoked, certifiedBy, model.AssetGroupSelectorNodeSource(source), "", "", "", "")
+	require.NoError(t, err)
+	err = suite.BHDatabase.InsertSelectorNode(testCtx, testAssetGroupTagId1, testSelectorId1, testNodeId2, model.AssetGroupCertificationPending, certifiedBy, model.AssetGroupSelectorNodeSource(source), "", "", "", "")
+	require.NoError(t, err)
+	err = suite.BHDatabase.InsertSelectorNode(testCtx, testAssetGroupTagId1, testSelectorId2, testNodeId1, model.AssetGroupCertificationPending, certifiedBy, model.AssetGroupSelectorNodeSource(source), "", "", "", "")
+	require.NoError(t, err)
+
+	t.Run("updates certification by selector node, certified", func(t *testing.T) {
+		inputs := []database.UpdateCertificationBySelectorNodeInput{updateInputCertify}
+		sqlFilter := model.SQLFilter{SQLString: "AND node_id = ?", Params: []any{updateInputCertify.NodeId}}
+		_, rowCountBefore, err := suite.BHDatabase.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, nil, 0, 0)
+		require.NoError(t, err)
+		err = suite.BHDatabase.UpdateCertificationBySelectorNode(testCtx, inputs)
+		require.NoError(t, err)
+		// confirm selector was updated
+		selectorNodes, count, err := suite.BHDatabase.GetSelectorNodesBySelectorIdsFilteredAndPaginated(testCtx, sqlFilter, sort, 0, 100, updateInputCertify.SelectorId)
+		require.NoError(t, err)
+		require.Equal(t, 1, count)
+		require.Equal(t, model.AssetGroupCertificationManual, selectorNodes[0].Certified)
+
+		//confirm only one history record was created
+		_, rowCountAfter, err := suite.BHDatabase.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, nil, 0, 0)
+		require.NoError(t, err)
+		require.Equal(t, rowCountBefore+1, rowCountAfter)
+	})
+
+	t.Run("updates certification by selector node, pending", func(t *testing.T) {
+		inputs := []database.UpdateCertificationBySelectorNodeInput{updateInputPending}
+		sqlFilter := model.SQLFilter{SQLString: "AND node_id = ?", Params: []any{updateInputPending.NodeId}}
+		_, rowCountBefore, err := suite.BHDatabase.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, nil, 0, 0)
+		require.NoError(t, err)
+		err = suite.BHDatabase.UpdateCertificationBySelectorNode(testCtx, inputs)
+		require.NoError(t, err)
+		// confirm selectors were updated
+		selectorNodes, count, err := suite.BHDatabase.GetSelectorNodesBySelectorIdsFilteredAndPaginated(testCtx, sqlFilter, sort, 0, 100, updateInputPending.SelectorId)
+		require.NoError(t, err)
+		require.Equal(t, 1, count)
+		require.Equal(t, model.AssetGroupCertificationPending, selectorNodes[0].Certified)
+
+		//confirm no history record were created
+		_, rowCountAfter, err := suite.BHDatabase.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, nil, 0, 0)
+		require.NoError(t, err)
+		require.Equal(t, rowCountBefore, rowCountAfter)
+	})
+
+	t.Run("updates certification by selector node, mix of pending and certified for single node ID", func(t *testing.T) {
+		inputs := []database.UpdateCertificationBySelectorNodeInput{updateInputCertify, updateInputPending}
+		sqlFilter := model.SQLFilter{SQLString: "AND node_id = ?", Params: []any{updateInputCertify.NodeId}}
+		_, rowCountBefore, err := suite.BHDatabase.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, nil, 0, 0)
+		require.NoError(t, err)
+		err = suite.BHDatabase.UpdateCertificationBySelectorNode(testCtx, inputs)
+		require.NoError(t, err)
+		// confirm selectors were updated
+		selectorNodes, count, err := suite.BHDatabase.GetSelectorNodesBySelectorIdsFilteredAndPaginated(testCtx, sqlFilter, sort, 0, 100, updateInputCertify.SelectorId, updateInputPending.SelectorId)
+		require.NoError(t, err)
+		require.Equal(t, 2, count)
+		require.Equal(t, model.AssetGroupCertificationManual, selectorNodes[0].Certified)
+		require.Equal(t, model.AssetGroupCertificationPending, selectorNodes[1].Certified)
+
+		//confirm only one history record was created
+		_, rowCountAfter, err := suite.BHDatabase.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, nil, 0, 0)
+		require.NoError(t, err)
+		require.Equal(t, rowCountBefore+1, rowCountAfter)
+	})
+
+	t.Run("updates certification by selector node, 2 nodes", func(t *testing.T) {
+		inputs := []database.UpdateCertificationBySelectorNodeInput{updateInputCertify, updateInputNode2}
+		_, rowCountBefore, err := suite.BHDatabase.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, nil, 0, 0)
+		require.NoError(t, err)
+		err = suite.BHDatabase.UpdateCertificationBySelectorNode(testCtx, inputs)
+		require.NoError(t, err)
+		// confirm selectors were updated
+		selectors, err := suite.BHDatabase.GetSelectorNodesBySelectorIds(testCtx, testSelectorId1)
+		require.NoError(t, err)
+		require.Equal(t, 2, len(selectors))
+		require.Equal(t, model.AssetGroupCertificationManual, selectors[0].Certified)
+		require.Equal(t, model.AssetGroupCertificationManual, selectors[1].Certified)
+
+		//confirm two history records created
+		_, rowCountAfter, err := suite.BHDatabase.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, nil, 0, 0)
+		require.NoError(t, err)
+		require.Equal(t, rowCountBefore+2, rowCountAfter)
+	})
+}
+
+func TestDatabase_GetAssetGroupSelectorNodeExpandedOrderedByIdAndPosition(t *testing.T) {
+	t.Parallel()
+	suite := setupIntegrationTestSuite(t)
+	defer teardownIntegrationTestSuite(t, &suite)
+
+	var (
+		testCtx         = context.Background()
+		testActor       = model.User{Unique: model.Unique{ID: uuid.FromStringOrNil("01234567-9012-4567-9012-456789012345")}}
+		testName        = "test selector name"
+		testDescription = "test description"
+		certifiedBy     = null.StringFrom("testy")
+		testObjectId1   = 1
+		testObjectId2   = 2
+		testNodeId1     = uint64(testObjectId1)
+		testNodeId2     = uint64(testObjectId2)
+		source          = 1
+		isDefault       = false
+		allowDisable    = true
+		autoCertify     = null.BoolFrom(false)
+		testSeeds       = []model.SelectorSeed{
+			{Type: model.SelectorTypeObjectId, Value: "ObjectID1234"},
+			{Type: model.SelectorTypeObjectId, Value: "ObjectID5678"},
+		}
+	)
+
+	tierTag, err := suite.BHDatabase.CreateAssetGroupTag(testCtx, model.AssetGroupTagTypeTier, model.User{}, "tier 1", testDescription, null.Int32From(2), null.BoolFrom(false), null.String{})
+	require.NoError(t, err)
+
+	labelTag, err := suite.BHDatabase.CreateAssetGroupTag(testCtx, model.AssetGroupTagTypeLabel, model.User{}, "label", testDescription, null.Int32{}, null.Bool{}, null.String{})
+	require.NoError(t, err)
+
+	selector, err := suite.BHDatabase.CreateAssetGroupTagSelector(testCtx, tierTag.ID, testActor, testName, testDescription, isDefault, allowDisable, autoCertify, testSeeds)
+	require.NoError(t, err)
+
+	err = suite.BHDatabase.InsertSelectorNode(testCtx, tierTag.ID, selector.ID, graph.ID(testNodeId1), model.AssetGroupCertificationManual, certifiedBy, model.AssetGroupSelectorNodeSource(source), "", "", "", "")
+	require.NoError(t, err)
+
+	err = suite.BHDatabase.InsertSelectorNode(testCtx, tierTag.ID, selector.ID, graph.ID(testNodeId2), model.AssetGroupCertificationManual, certifiedBy, model.AssetGroupSelectorNodeSource(source), "", "", "", "")
+	require.NoError(t, err)
+
+	err = suite.BHDatabase.InsertSelectorNode(testCtx, tierTag.ID, selector.ID, graph.ID(testNodeId1), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "", "", "", "")
+	require.NoError(t, err)
+
+	err = suite.BHDatabase.InsertSelectorNode(testCtx, labelTag.ID, selector.ID, graph.ID(testNodeId1), model.AssetGroupCertificationManual, certifiedBy, model.AssetGroupSelectorNodeSource(source), "", "", "", "")
+	require.NoError(t, err)
+
+	tests := map[string]struct {
+		Input          []int
+		ExpectedLength int
+	}{
+		"returns all selected nodes, ignores tags and auto certified nodes": {
+			Input:          []int{testObjectId1, testObjectId2},
+			ExpectedLength: 2,
+		},
+		"returns empty slice if no nodes found": {
+			Input:          []int{3},
+			ExpectedLength: 0,
+		},
+		"returns empty slice if no node IDs passed in": {
+			Input:          nil,
+			ExpectedLength: 0,
+		},
+	}
+
+	for name, test := range tests {
+		t.Run(name, func(t *testing.T) {
+			if got, err := suite.BHDatabase.GetAssetGroupSelectorNodeExpandedOrderedByIdAndPosition(testCtx, test.Input...); err != nil {
+				t.Fatalf("error getting selector node expanded ignore autocertify: %v", err)
+			} else if len(got) != test.ExpectedLength {
+				t.Fatalf("got %d expected %d", len(got), test.ExpectedLength)
+			}
+		})
+	}
+}
+
+func TestDatabase_GetAggregatedSelectorNodesCertification(t *testing.T) {
+	t.Parallel()
+	suite := setupIntegrationTestSuite(t)
+	defer teardownIntegrationTestSuite(t, &suite)
+
+	var (
+		testCtx         = context.Background()
+		testActor       = model.User{Unique: model.Unique{ID: uuid.FromStringOrNil("01234567-9012-4567-9012-456789012345")}}
+		testCertifiedBy = "testy"
+		certifiedBy     = null.StringFrom(testCertifiedBy)
+		source          = 1
+	)
+
+	// create a test zone at position 2
+	tier1, err := suite.BHDatabase.CreateAssetGroupTag(testCtx, model.AssetGroupTagTypeTier, testActor, "Test T1 Zone", "Test zone description", null.Int32From(2), null.BoolFrom(false), null.String{})
+	require.NoError(t, err)
+
+	// create a test zone at position 3
+	tier2, err := suite.BHDatabase.CreateAssetGroupTag(testCtx, model.AssetGroupTagTypeTier, testActor, "Test T2 Zone", "Test zone description", null.Int32From(3), null.BoolFrom(false), null.String{})
+	require.NoError(t, err)
+
+	// Zone 0 is added by the migration and is ID 1
+	sel0, err := suite.BHDatabase.CreateAssetGroupTagSelector(testCtx, 1, model.User{}, "Test T0 selector", "description", false, true, null.BoolFrom(false), []model.SelectorSeed{})
+	require.NoError(t, err)
+
+	sel0_1, err := suite.BHDatabase.CreateAssetGroupTagSelector(testCtx, 1, model.User{}, "Test T0 selector number 2", "description", false, true, null.BoolFrom(false), []model.SelectorSeed{})
+	require.NoError(t, err)
+
+	sel0_2, err := suite.BHDatabase.CreateAssetGroupTagSelector(testCtx, 1, model.User{}, "Test T0 selector number 3", "description", false, true, null.BoolFrom(false), []model.SelectorSeed{})
+	require.NoError(t, err)
+
+	sel0_3, err := suite.BHDatabase.CreateAssetGroupTagSelector(testCtx, 1, model.User{}, "Test T0 selector number 4", "description", false, true, null.BoolFrom(false), []model.SelectorSeed{})
+	require.NoError(t, err)
+
+	sel1, err := suite.BHDatabase.CreateAssetGroupTagSelector(testCtx, tier1.ID, model.User{}, "Test T1 selector", "description", false, true, null.BoolFrom(false), []model.SelectorSeed{})
+	require.NoError(t, err)
+
+	sel2, err := suite.BHDatabase.CreateAssetGroupTagSelector(testCtx, tier2.ID, model.User{}, "Test T2 selector", "description", false, true, null.BoolFrom(false), []model.SelectorSeed{})
+	require.NoError(t, err)
+
+	t.Run("Multiple nodes - verify highest tier wins", func(t *testing.T) {
+		testNodeId := uint64(1)
+
+		// a selector for T0 selects this node
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0.ID, graph.ID(testNodeId), model.AssetGroupCertificationPending, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0")
+		require.NoError(t, err)
+
+		// a selector for T1 also selects this node
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, tier1.ID, sel1.ID, graph.ID(testNodeId), model.AssetGroupCertificationPending, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_1", "environment", "objid", "NodeSelectedByT1")
+		require.NoError(t, err)
+
+		// a selector for T2 also selects this node
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, tier2.ID, sel2.ID, graph.ID(testNodeId), model.AssetGroupCertificationPending, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_2", "environment", "objid", "NodeSelectedByT2")
+		require.NoError(t, err)
+
+		// filtering on the nodes from this test only
+		nodeCertifications, count, err := suite.BHDatabase.GetAggregatedSelectorNodesCertification(testCtx, model.SQLFilter{SQLString: "node_id = 1"}, 0, 0)
+		require.NoError(t, err)
+
+		// there should only be a single node returned
+		require.Equal(t, 1, count)
+		// it should be the one associated with T0
+		require.Equal(t, "NodeSelectedByT0", nodeCertifications[0].NodeName)
+	})
+
+	t.Run("Multiple nodes - verify correct hybrid output", func(t *testing.T) {
+		testNodeId := uint64(30)
+
+		// a selector for T0 selects this node
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0.ID, graph.ID(testNodeId), model.AssetGroupCertificationPending, null.StringFrom("Sel0_1_NoCertifier"), model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0")
+		require.NoError(t, err)
+
+		timeBeforeSel0_1_NodeInserted := time.Now().UTC()
+
+		// another selector for T0 selects this node
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0_1.ID, graph.ID(testNodeId), model.AssetGroupCertificationManual, null.StringFrom("Sel0_1_ManualCertifier"), model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0")
+		require.NoError(t, err)
+
+		// a selector for T1 also selects this node
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, tier1.ID, sel1.ID, graph.ID(testNodeId), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_1", "environment", "objid", "NodeSelectedByT1")
+		require.NoError(t, err)
+
+		// a selector for T2 also selects this node
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, tier2.ID, sel2.ID, graph.ID(testNodeId), model.AssetGroupCertificationPending, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_2", "environment", "objid", "NodeSelectedByT2")
+		require.NoError(t, err)
+
+		// filtering on the nodes from this test only
+		nodeCertifications, count, err := suite.BHDatabase.GetAggregatedSelectorNodesCertification(testCtx, model.SQLFilter{SQLString: "node_id = 30"}, 0, 0)
+		require.NoError(t, err)
+
+		// there should only be a single node returned
+		require.Equal(t, 1, count)
+		// it should have the highest certification value associated with T0
+		require.Equal(t, model.AssetGroupCertificationManual, nodeCertifications[0].Certified)
+		// it should be associated with T0
+		require.Equal(t, 1, nodeCertifications[0].AssetGroupTagId)
+		// it should have a timestamp of the first node inserted for this tier
+		require.True(t, nodeCertifications[0].CreatedAt.Before(timeBeforeSel0_1_NodeInserted))
+	})
+
+	t.Run("Multiple nodes - verify highest certify wins", func(t *testing.T) {
+		testNodeId := uint64(2)
+		// this one has certification revoked
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0.ID, graph.ID(testNodeId), model.AssetGroupCertificationRevoked, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_CertRevoked")
+		require.NoError(t, err)
+
+		// no certification
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0_1.ID, graph.ID(testNodeId), model.AssetGroupCertificationPending, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_CertNone")
+		require.NoError(t, err)
+
+		// manual certification
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0_2.ID, graph.ID(testNodeId), model.AssetGroupCertificationManual, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_CertManual")
+		require.NoError(t, err)
+
+		// auto certification
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0_3.ID, graph.ID(testNodeId), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_CertAuto")
+		require.NoError(t, err)
+
+		// filtering on the nodes from this test only
+		nodeCertifications, count, err := suite.BHDatabase.GetAggregatedSelectorNodesCertification(testCtx, model.SQLFilter{SQLString: "node_id = 2"}, 0, 0)
+		require.NoError(t, err)
+
+		// there should only be a single node returned
+		require.Equal(t, 1, count)
+		// it should be the one that had auto certify
+		require.Equal(t, "NodeSelectedByT0_CertAuto", nodeCertifications[0].NodeName)
+		require.Equal(t, model.AssetGroupCertificationAuto, nodeCertifications[0].Certified)
+	})
+
+	t.Run("Multiple nodes - verify earliest create date wins", func(t *testing.T) {
+		testNodeId := uint64(3)
+		// created first
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0.ID, graph.ID(testNodeId), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_First")
+		require.NoError(t, err)
+
+		// created second
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0_1.ID, graph.ID(testNodeId), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_Second")
+		require.NoError(t, err)
+
+		// created third
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0_2.ID, graph.ID(testNodeId), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_Third")
+		require.NoError(t, err)
+
+		// created fourth
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0_3.ID, graph.ID(testNodeId), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_Fourth")
+		require.NoError(t, err)
+
+		// filtering on the nodes from this test only
+		nodeCertifications, count, err := suite.BHDatabase.GetAggregatedSelectorNodesCertification(testCtx, model.SQLFilter{SQLString: "node_id = 3"}, 0, 0)
+		require.NoError(t, err)
+
+		// there should only be a single node returned
+		require.Equal(t, 1, count)
+		// it should be the one created first
+		require.Equal(t, "NodeSelectedByT0_First", nodeCertifications[0].NodeName)
+	})
+
+	t.Run("test pagination", func(t *testing.T) {
+		// create some nodes, all selected by a t0 selector
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0.ID, graph.ID(uint64(10)), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_First")
+		require.NoError(t, err)
+
+		// created second
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0.ID, graph.ID(uint64(11)), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_Second")
+		require.NoError(t, err)
+
+		// created third
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0.ID, graph.ID(uint64(12)), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_Third")
+		require.NoError(t, err)
+
+		// created fourth
+		err = suite.BHDatabase.InsertSelectorNode(testCtx, 1, sel0.ID, graph.ID(uint64(13)), model.AssetGroupCertificationAuto, certifiedBy, model.AssetGroupSelectorNodeSource(source), "kind_0", "environment", "objid", "NodeSelectedByT0_Fourth")
+		require.NoError(t, err)
+
+		// filtering on the nodes from this test only
+		nodeCertifications, count, err := suite.BHDatabase.GetAggregatedSelectorNodesCertification(testCtx, model.SQLFilter{SQLString: "node_id BETWEEN 10 AND 13"}, 0, 0)
+		require.NoError(t, err)
+
+		// verify 4 out of 4 nodes returned
+		require.Equal(t, 4, len(nodeCertifications))
+		require.Equal(t, 4, count)
+
+		// skip the first 2
+		nodeCertifications, count, err = suite.BHDatabase.GetAggregatedSelectorNodesCertification(testCtx, model.SQLFilter{SQLString: "node_id BETWEEN 10 AND 13"}, 2, 0)
+		require.NoError(t, err)
+
+		// verify 2 out of 4 nodes returned
+		require.Equal(t, 2, len(nodeCertifications))
+		require.Equal(t, 4, count)
+		require.Equal(t, "NodeSelectedByT0_Third", nodeCertifications[0].NodeName)
+
+		// limit to 2
+		nodeCertifications, count, err = suite.BHDatabase.GetAggregatedSelectorNodesCertification(testCtx, model.SQLFilter{SQLString: "node_id BETWEEN 10 AND 13"}, 0, 2)
+		require.NoError(t, err)
+
+		// verify 2 out of 4 nodes returned
+		require.Equal(t, 2, len(nodeCertifications))
+		require.Equal(t, 4, count)
+		require.Equal(t, "NodeSelectedByT0_First", nodeCertifications[0].NodeName)
+	})
+}
