@@ -48,6 +48,7 @@ const (
 	TrustedProxiesConfig       ParameterKey = "http.trusted_proxies"
 	FedEULACustomTextKey       ParameterKey = "eula.custom_text"
 	TierManagementParameterKey ParameterKey = "analysis.tiering"
+	StaleClientUpdatedLogicKey ParameterKey = "pipeline.updated_stale_client"
 )
 
 const (
@@ -92,7 +93,7 @@ func (s *Parameter) IsValidKey(parameterKey ParameterKey) bool {
 // IsProtectedKey These keys should not be updatable by users
 func (s *Parameter) IsProtectedKey(parameterKey ParameterKey) bool {
 	switch parameterKey {
-	case ScheduledAnalysis, TrustedProxiesConfig, FedEULACustomTextKey, TierManagementParameterKey, SessionTTLHours:
+	case ScheduledAnalysis, TrustedProxiesConfig, FedEULACustomTextKey, TierManagementParameterKey, SessionTTLHours, StaleClientUpdatedLogicKey:
 		return true
 	default:
 		return false
@@ -133,6 +134,8 @@ func (s *Parameter) Validate() utils.Errors {
 		v = &FedEULACustomTextParameter{}
 	case SessionTTLHours:
 		v = &SessionTTLHoursParameter{}
+	case StaleClientUpdatedLogicKey:
+		v = &StaleClientUpdatedLogic{}
 	default:
 		return utils.Errors{errors.New("invalid key")}
 	}
@@ -428,3 +431,21 @@ func GetSessionTTLHours(ctx context.Context, service ParameterService) time.Dura
 
 	return time.Hour * time.Duration(result.Hours)
 }
+
+// StaleClientUpdatedLogic
+
+type StaleClientUpdatedLogic struct {
+	Enabled bool `json:"enabled,omitempty"`
+}
+
+func GetStaleClientUpdatedLogic(ctx context.Context, service ParameterService) bool {
+	var result StaleClientUpdatedLogic
+
+	if cfg, err := service.GetConfigurationParameter(ctx, StaleClientUpdatedLogicKey); err != nil {
+		slog.WarnContext(ctx, "Failed to fetch StaleClientLogic configuration; returning default values")
+	} else if err := cfg.Map(&result); err != nil {
+		slog.WarnContext(ctx, fmt.Sprintf("Invalid StaleClientLogic configuration supplied, %v. returning default values.", err))
+	}
+
+	return result.Enabled
+}
