@@ -428,17 +428,18 @@ func UserAssociations() []string {
 }
 
 type User struct {
-	SSOProvider   *SSOProvider `json:"-" `
-	SSOProviderID null.Int32   `json:"sso_provider_id,omitempty"`
-	AuthSecret    *AuthSecret  `gorm:"constraint:OnDelete:CASCADE;"`
-	AuthTokens    AuthTokens   `json:"-" gorm:"constraint:OnDelete:CASCADE;"`
-	Roles         Roles        `json:"roles" gorm:"many2many:users_roles"`
-	FirstName     null.String  `json:"first_name"`
-	LastName      null.String  `json:"last_name"`
-	EmailAddress  null.String  `json:"email_address"`
-	PrincipalName string       `json:"principal_name" gorm:"unique;index"`
-	LastLogin     time.Time    `json:"last_login"`
-	IsDisabled    bool         `json:"is_disabled"`
+	SSOProvider     *SSOProvider `json:"-" `
+	SSOProviderID   null.Int32   `json:"sso_provider_id,omitempty"`
+	AuthSecret      *AuthSecret  `gorm:"constraint:OnDelete:CASCADE;"`
+	AuthTokens      AuthTokens   `json:"-" gorm:"constraint:OnDelete:CASCADE;"`
+	Roles           Roles        `json:"roles" gorm:"many2many:users_roles"`
+	FirstName       null.String  `json:"first_name"`
+	LastName        null.String  `json:"last_name"`
+	EmailAddress    null.String  `json:"email_address"`
+	PrincipalName   string       `json:"principal_name" gorm:"unique;index"`
+	LastLogin       time.Time    `json:"last_login"`
+	IsDisabled      bool         `json:"is_disabled"`
+	AllEnvironments bool         `json:"all_environments"`
 
 	// EULA Acceptance does not pertain to Bloodhound Community Edition; this flag is used for Bloodhound Enterprise users.
 	// This value is automatically set to true for Bloodhound Community Edition in the patchEULAAcceptance and CreateUser functions.
@@ -449,15 +450,16 @@ type User struct {
 
 func (s *User) AuditData() AuditData {
 	return AuditData{
-		"id":              s.ID,
-		"principal_name":  s.PrincipalName,
-		"first_name":      s.FirstName.ValueOrZero(),
-		"last_name":       s.LastName.ValueOrZero(),
-		"email_address":   s.EmailAddress.ValueOrZero(),
-		"roles":           s.Roles.IDs(),
-		"sso_provider_id": s.SSOProviderID.ValueOrZero(),
-		"is_disabled":     s.IsDisabled,
-		"eula_accepted":   s.EULAAccepted,
+		"id":               s.ID,
+		"principal_name":   s.PrincipalName,
+		"first_name":       s.FirstName.ValueOrZero(),
+		"last_name":        s.LastName.ValueOrZero(),
+		"email_address":    s.EmailAddress.ValueOrZero(),
+		"roles":            s.Roles.IDs(),
+		"sso_provider_id":  s.SSOProviderID.ValueOrZero(),
+		"is_disabled":      s.IsDisabled,
+		"eula_accepted":    s.EULAAccepted,
+		"all_environments": s.AllEnvironments,
 	}
 }
 
