@@ -27,8 +27,8 @@ import (
 	"github.com/bloodhoundad/azurehound/v2/enums"
 	"github.com/bloodhoundad/azurehound/v2/models"
 	azureModels "github.com/bloodhoundad/azurehound/v2/models/azure"
-	"github.com/specterops/bloodhound/ein"
-	"github.com/specterops/bloodhound/graphschema/azure"
+	"github.com/specterops/bloodhound/packages/go/ein"
+	"github.com/specterops/bloodhound/packages/go/graphschema/azure"
 )
 
 const (
@@ -144,6 +144,8 @@ func getKindConverter(kind enums.Kind) func(json.RawMessage, *ConvertedAzureData
 		return convertAzureAutomationAccountRoleAssignment
 	case enums.KindAZRoleManagementPolicyAssignment:
 		return convertAzureRoleManagementPolicyAssignment
+	case enums.KindAZRoleEligibilityScheduleInstance:
+		return convertAzureRoleEligibilityScheduleInstance
 	default:
 		// TODO: we should probably have a hook or something to log the unknown type
 		return func(rm json.RawMessage, cd *ConvertedAzureData, now time.Time) {}
@@ -727,3 +729,14 @@ func convertAzureRoleManagementPolicyAssignment(raw json.RawMessage, converted *
 		converted.RelProps = append(converted.RelProps, relationships...)
 	}
 }
+
+func convertAzureRoleEligibilityScheduleInstance(raw json.RawMessage, converted *ConvertedAzureData, ingestTime time.Time) {
+	var data models.RoleEligibilityScheduleInstance
+
+	if err := json.Unmarshal(raw, &data); err != nil {
+		slog.Error(fmt.Sprintf(SerialError, "azure role eligibility schedule instance", err))
+	} else {
+		relProps := ein.ConvertAzureRoleEligibilityScheduleInstanceToRel(data)
+		converted.RelProps = append(converted.RelProps, relProps...)
+	}
+}
