@@ -19,14 +19,7 @@ import { BasePath, BaseSVG, BaseSVGProps } from './utils';
 
 export const LargeRightArrow: React.FC<BaseSVGProps> = (props) => {
     return (
-        <BaseSVG
-            name='large-right-arrow'
-            width='7'
-            height='60'
-            viewBox='0 0 7 60'
-            fill='none'
-            xmlns='http://www.w3.org/2000/svg'
-            {...props}>
+        <BaseSVG name='large-right-arrow' viewBox='0 0 7 60' fill='none' xmlns='http://www.w3.org/2000/svg' {...props}>
             <BasePath d='M6 30.2522L1 1V59L6 30.2522Z' strokeLinejoin='round' />
         </BaseSVG>
     );
