@@ -20,13 +20,16 @@ import { FC } from 'react';
 const References: FC = () => {
     return (
         <Box sx={{ overflowX: 'auto' }}>
-            <Link target='_blank' rel='noopener' href='https://blog.netspi.com/azure-automation-accounts-key-stores/'>
+            <Link
+                target='_blank'
+                rel='noopener noreferrer'
+                href='https://blog.netspi.com/azure-automation-accounts-key-stores/'>
                 https://blog.netspi.com/azure-automation-accounts-key-stores/
             </Link>
             <br />
             <Link
                 target='_blank'
-                rel='noopener'
+                rel='noopener noreferrer'
                 href='https://powerzure.readthedocs.io/en/latest/Functions/operational.html#export-azurekeyvaultcontent'>
                 https://powerzure.readthedocs.io/en/latest/Functions/operational.html#export-azurekeyvaultcontent
             </Link>
