@@ -13,24 +13,34 @@
 // limitations under the License.
 //
 // SPDX-License-Identifier: Apache-2.0
+import { findIconDefinition } from '@fortawesome/fontawesome-svg-core';
+import { IconName } from '@fortawesome/free-solid-svg-icons';
 import {
     AssetGroupTag,
     AssetGroupTagMemberListItem,
     AssetGroupTagSelector,
+    AssetGroupTagType,
     AssetGroupTagTypeLabel,
     AssetGroupTagTypeOwned,
-    AssetGroupTagTypes,
-    AssetGroupTagTypeTier,
+    AssetGroupTagTypeZone,
     CreateAssetGroupTagRequest,
     CreateSelectorRequest,
     RequestOptions,
     UpdateAssetGroupTagRequest,
     UpdateSelectorRequest,
 } from 'js-client-library';
+import { useEffect, useState } from 'react';
 import { useInfiniteQuery, useMutation, useQuery, useQueryClient } from 'react-query';
 import { SortOrder } from '../../types';
-import { apiClient } from '../../utils';
-import { createPaginatedFetcher, PageParam } from '../../utils/paginatedFetcher';
+import {
+    DEFAULT_GLYPH_BACKGROUND_COLOR,
+    DEFAULT_GLYPH_COLOR,
+    GLYPH_SCALE,
+    GenericQueryOptions,
+    apiClient,
+    getModifiedSvgUrlFromIcon,
+} from '../../utils';
+import { PageParam, createPaginatedFetcher } from '../../utils/paginatedFetcher';
 import { useFeatureFlag } from '../useFeatureFlags';
 
 interface CreateAssetGroupTagParams {
@@ -57,63 +67,152 @@ export interface PatchSelectorParams extends DeleteSelectorParams {
 
 const PAGE_SIZE = 25;
 
-export const zoneManagementKeys = {
-    all: ['zone-management'] as const,
-    tags: () => [...zoneManagementKeys.all, 'tags'] as const,
-    tagDetail: (tagId: string | number) => [...zoneManagementKeys.tags(), 'tagId', tagId] as const,
-    selectors: () => [...zoneManagementKeys.all, 'selectors'] as const,
-    selectorsByTag: (tagId: string | number) => [...zoneManagementKeys.selectors(), 'tag', tagId] as const,
+export const privilegeZonesKeys = {
+    all: ['privilege-zones'] as const,
+    tags: () => [...privilegeZonesKeys.all, 'tags'] as const,
+    tagDetail: (tagId: string | number) => [...privilegeZonesKeys.tags(), 'tagId', tagId] as const,
+    selectors: () => [...privilegeZonesKeys.all, 'selectors'] as const,
+    selectorsByTag: (tagId: string | number, sortOrder: SortOrder = undefined, environments: string[] = []) =>
+        [...privilegeZonesKeys.selectors(), 'tag', tagId, sortOrder, ...environments] as const,
     selectorDetail: (tagId: string | number, selectorId: string | number) =>
-        [...zoneManagementKeys.selectorsByTag(tagId), 'selectorId', selectorId] as const,
-    members: () => [...zoneManagementKeys.all, 'members'] as const,
-    membersByTag: (tagId: string | number, sortOrder: SortOrder) =>
-        [...zoneManagementKeys.members(), 'tag', tagId, sortOrder] as const,
-    membersByTagAndSelector: (tagId: string | number, selectorId: string | number | undefined, sortOrder: SortOrder) =>
-        ['tag', tagId, 'selector', selectorId, sortOrder] as const,
+        [...privilegeZonesKeys.selectorsByTag(tagId), 'selectorId', selectorId] as const,
+    members: () => [...privilegeZonesKeys.all, 'members'] as const,
+    membersByTag: (tagId: string | number, sortOrder: SortOrder, environments: string[] = []) =>
+        [...privilegeZonesKeys.members(), 'tag', tagId, sortOrder, ...environments] as const,
+    membersByTagAndSelector: (
+        tagId: string | number,
+        selectorId: string | number | undefined,
+        sortOrder: SortOrder,
+        environments: string[] = []
+    ) => ['tag', tagId, 'selector', selectorId, sortOrder, ...environments] as const,
 };
 
-export const getAssetGroupTags = () =>
+const getAssetGroupTags = (options: RequestOptions) =>
     apiClient
         .getAssetGroupTags({
+            ...options,
             params: {
                 counts: true,
             },
         })
-        .then((res) => {
-            return res.data.data['tags'];
-        });
+        .then((res) => res.data.data.tags);
 
-export const useTagsQuery = (filter?: (value: AssetGroupTag, index: number, array: AssetGroupTag[]) => boolean) =>
-    useQuery({
-        queryKey: zoneManagementKeys.tags(),
-        queryFn: () => getAssetGroupTags(),
-        select: (data) => (filter ? data.filter(filter) : data),
+const glyphQualifier = (glyph: string | null) => !glyph?.includes('http');
+
+const glyphTransformer = (glyph: string, darkMode?: boolean): string => {
+    const iconDefiniton = findIconDefinition({ prefix: 'fas', iconName: glyph as IconName });
+
+    if (!iconDefiniton) return '';
+
+    const glyphIconUrl = getModifiedSvgUrlFromIcon(iconDefiniton, {
+        styles: {
+            'transform-origin': 'center',
+            scale: GLYPH_SCALE,
+            background: darkMode ? DEFAULT_GLYPH_COLOR : DEFAULT_GLYPH_BACKGROUND_COLOR,
+            color: darkMode ? DEFAULT_GLYPH_BACKGROUND_COLOR : DEFAULT_GLYPH_COLOR,
+        },
     });
 
-export const getAssetGroupTagSelectors = (tagId: string | number, skip: number = 0, limit: number = PAGE_SIZE) =>
+    return glyphIconUrl;
+};
+
+export interface GlyphUtils {
+    qualifier?: (glyph: string | null) => boolean;
+    transformer: (glyph: string, darkMode?: boolean) => string;
+}
+
+export const glyphUtils: GlyphUtils = {
+    qualifier: glyphQualifier,
+    transformer: glyphTransformer,
+};
+
+export const createGlyphMapFromTags = (
+    tags: AssetGroupTag[] | undefined,
+    utils: GlyphUtils,
+    darkMode?: boolean
+): Record<string, string> => {
+    const glyphMap: Record<string, string> = {};
+    const { qualifier = () => true, transformer } = utils;
+
+    tags?.forEach((tag) => {
+        const underscoredTagName = tag.name.split(' ').join('_');
+
+        if (tag.glyph !== null && qualifier(tag.glyph)) {
+            const glyphValue = transformer(tag.glyph, darkMode);
+
+            if (glyphValue !== '') glyphMap[`Tag_${underscoredTagName}`] = glyphValue;
+        }
+    });
+
+    return glyphMap;
+};
+
+export const getGlyphFromKinds = (kinds: string[] = [], tagGlyphMap: Record<string, string> = {}): string | null => {
+    for (let index = kinds.length - 1; index > -1; index--) {
+        const kind = kinds[index];
+        if (!kind.includes('Tag_')) continue;
+
+        if (tagGlyphMap[kind]) return tagGlyphMap[kind];
+    }
+    return null;
+};
+
+export const useTagGlyphs = (glyphUtils: GlyphUtils, darkMode?: boolean) => {
+    const [glyphMap, setGlyphMap] = useState<Record<string, string>>({});
+    const tagsQuery = useAssetGroupTags();
+
+    useEffect(() => {
+        if (!tagsQuery.data) return;
+
+        const newMap = createGlyphMapFromTags(tagsQuery.data, glyphUtils, darkMode);
+        setGlyphMap(newMap);
+    }, [tagsQuery.data, glyphUtils, darkMode]);
+
+    return glyphMap;
+};
+
+export const useTagsQuery = (queryOptions?: GenericQueryOptions<AssetGroupTag[]>) =>
+    useQuery({
+        queryKey: privilegeZonesKeys.tags() as unknown as string[],
+        queryFn: ({ signal }) => getAssetGroupTags({ signal }),
+        ...queryOptions,
+    });
+
+export const getAssetGroupTagSelectors = (
+    tagId: string | number,
+    skip: number = 0,
+    limit: number = PAGE_SIZE,
+    sortOrder: SortOrder = 'asc',
+    environments: string[] = []
+) =>
     createPaginatedFetcher(
         () =>
-            apiClient.getAssetGroupTagSelectors(tagId, {
-                params: {
-                    skip,
-                    limit,
-                    counts: true,
-                },
-            }),
+            apiClient.getAssetGroupTagSelectors(
+                tagId,
+                skip,
+                limit,
+                sortOrder === 'asc' ? 'name' : '-name',
+                environments,
+                { params: { counts: true } }
+            ),
         'selectors',
         skip,
         limit
     );
 
-export const useSelectorsInfiniteQuery = (tagId: string | number | undefined) =>
+export const useSelectorsInfiniteQuery = (
+    tagId: string | number | undefined,
+    sortOrder: SortOrder,
+    environments: string[] = []
+) =>
     useInfiniteQuery<{
         items: AssetGroupTagSelector[];
         nextPageParam?: PageParam;
     }>({
-        queryKey: zoneManagementKeys.selectorsByTag(tagId!),
+        queryKey: privilegeZonesKeys.selectorsByTag(tagId!, sortOrder, environments),
         queryFn: ({ pageParam = { skip: 0, limit: PAGE_SIZE } }) => {
             if (!tagId) return Promise.reject('No tag ID provided for selectors request');
-            return getAssetGroupTagSelectors(tagId, pageParam.skip, pageParam.limit);
+            return getAssetGroupTagSelectors(tagId, pageParam.skip, pageParam.limit, sortOrder, environments);
         },
         getNextPageParam: (lastPage) => lastPage.nextPageParam,
         enabled: tagId !== undefined,
@@ -123,35 +222,42 @@ export const getAssetGroupTagMembers = (
     tagId: number | string,
     skip = 0,
     limit = PAGE_SIZE,
-    sortOrder: SortOrder = 'asc'
+    sortOrder: SortOrder = 'asc',
+    environments?: string[]
 ) =>
     createPaginatedFetcher<AssetGroupTagMemberListItem>(
-        () => apiClient.getAssetGroupTagMembers(tagId, skip, limit, sortOrder === 'asc' ? 'name' : '-name'),
+        () =>
+            apiClient.getAssetGroupTagMembers(tagId, skip, limit, sortOrder === 'asc' ? 'name' : '-name', environments),
         'members',
         skip,
         limit
     );
 
-export const useTagMembersInfiniteQuery = (tagId: number | string | undefined, sortOrder: SortOrder) =>
+export const useTagMembersInfiniteQuery = (
+    tagId: number | string | undefined,
+    sortOrder: SortOrder,
+    environments?: string[]
+) =>
     useInfiniteQuery<{
         items: AssetGroupTagMemberListItem[];
         nextPageParam?: PageParam;
     }>({
-        queryKey: zoneManagementKeys.membersByTag(tagId!, sortOrder),
+        queryKey: privilegeZonesKeys.membersByTag(tagId!, sortOrder, environments),
         queryFn: ({ pageParam = { skip: 0, limit: PAGE_SIZE } }) => {
             if (!tagId) return Promise.reject('No tag ID provided for tag members request');
-            return getAssetGroupTagMembers(tagId, pageParam.skip, pageParam.limit, sortOrder);
+            return getAssetGroupTagMembers(tagId, pageParam.skip, pageParam.limit, sortOrder, environments);
         },
         getNextPageParam: (lastPage) => lastPage.nextPageParam,
         enabled: tagId !== undefined,
     });
 
-export const getAssetGroupSelectorMembers = (
+export const getAssetGroupTagSelectorMembers = (
     tagId: number | string,
     selectorId: number | string,
     skip: number = 0,
     limit: number = PAGE_SIZE,
-    sortOrder: SortOrder = 'asc'
+    sortOrder: SortOrder = 'asc',
+    environments?: string[]
 ) =>
     createPaginatedFetcher(
         () =>
@@ -160,7 +266,8 @@ export const getAssetGroupSelectorMembers = (
                 selectorId,
                 skip,
                 limit,
-                sortOrder === 'asc' ? 'name' : '-name'
+                sortOrder === 'asc' ? 'name' : '-name',
+                environments
             ),
         'members',
         skip,
@@ -170,17 +277,25 @@ export const getAssetGroupSelectorMembers = (
 export const useSelectorMembersInfiniteQuery = (
     tagId: number | string | undefined,
     selectorId: number | string | undefined,
-    sortOrder: SortOrder
+    sortOrder: SortOrder,
+    environments?: string[]
 ) =>
     useInfiniteQuery<{
         items: AssetGroupTagMemberListItem[];
         nextPageParam?: PageParam;
     }>({
-        queryKey: zoneManagementKeys.membersByTagAndSelector(tagId!, selectorId, sortOrder),
+        queryKey: privilegeZonesKeys.membersByTagAndSelector(tagId!, selectorId, sortOrder, environments),
         queryFn: ({ pageParam = { skip: 0, limit: PAGE_SIZE } }) => {
             if (!tagId) return Promise.reject('No tag ID available to get selector members');
             if (!selectorId) return Promise.reject('No selector ID available to get selector members');
-            return getAssetGroupSelectorMembers(tagId, selectorId, pageParam.skip, pageParam.limit, sortOrder);
+            return getAssetGroupTagSelectorMembers(
+                tagId,
+                selectorId,
+                pageParam.skip,
+                pageParam.limit,
+                sortOrder,
+                environments
+            );
         },
         getNextPageParam: (lastPage) => lastPage.nextPageParam,
         enabled: tagId !== undefined && selectorId !== undefined,
@@ -198,7 +313,7 @@ export const useCreateSelector = (tagId: string | number | undefined) => {
     const queryClient = useQueryClient();
     return useMutation(createSelector, {
         onSettled: async () => {
-            await queryClient.invalidateQueries(zoneManagementKeys.selectorsByTag(tagId!));
+            await queryClient.invalidateQueries(privilegeZonesKeys.selectorsByTag(tagId!));
         },
     });
 };
@@ -215,7 +330,7 @@ export const usePatchSelector = (tagId: string | number) => {
     const queryClient = useQueryClient();
     return useMutation(patchSelector, {
         onSettled: async () => {
-            await queryClient.invalidateQueries(zoneManagementKeys.selectorsByTag(tagId));
+            await queryClient.invalidateQueries(privilegeZonesKeys.selectorsByTag(tagId));
         },
     });
 };
@@ -227,15 +342,15 @@ export const useDeleteSelector = () => {
     const queryClient = useQueryClient();
     return useMutation(deleteSelector, {
         onSettled: async (_data, _error, variables) => {
-            queryClient.invalidateQueries(zoneManagementKeys.selectorsByTag(variables.tagId));
-            queryClient.invalidateQueries(zoneManagementKeys.selectorDetail(variables.tagId, variables.selectorId));
+            queryClient.invalidateQueries(privilegeZonesKeys.selectorsByTag(variables.tagId));
+            queryClient.invalidateQueries(privilegeZonesKeys.selectorDetail(variables.tagId, variables.selectorId));
         },
     });
 };
 
 export const useSelectorInfo = (tagId: string, selectorId: string) =>
     useQuery({
-        queryKey: zoneManagementKeys.selectorDetail(tagId, selectorId),
+        queryKey: privilegeZonesKeys.selectorDetail(tagId, selectorId),
         queryFn: async ({ signal }) => {
             const response = await apiClient.getAssetGroupTagSelector(tagId, selectorId, { signal });
             return response.data.data['selector'];
@@ -255,7 +370,7 @@ export const useCreateAssetGroupTag = () => {
     const queryClient = useQueryClient();
     return useMutation(createAssetGroupTag, {
         onSettled: async () => {
-            await queryClient.invalidateQueries(zoneManagementKeys.tags());
+            await queryClient.invalidateQueries(privilegeZonesKeys.tags());
         },
     });
 };
@@ -272,8 +387,8 @@ export const usePatchAssetGroupTag = (tagId: string | number) => {
     const queryClient = useQueryClient();
     return useMutation(patchAssetGroupTag, {
         onSettled: async () => {
-            await queryClient.invalidateQueries(zoneManagementKeys.tags());
-            await queryClient.invalidateQueries(zoneManagementKeys.tagDetail(tagId));
+            await queryClient.invalidateQueries(privilegeZonesKeys.tags());
+            await queryClient.invalidateQueries(privilegeZonesKeys.tagDetail(tagId));
         },
     });
 };
@@ -285,15 +400,15 @@ export const useDeleteAssetGroupTag = () => {
     const queryClient = useQueryClient();
     return useMutation(deleteAssetGroupTag, {
         onSettled: async (_data, _error, tagId) => {
-            queryClient.invalidateQueries(zoneManagementKeys.tags());
-            queryClient.invalidateQueries(zoneManagementKeys.tagDetail(tagId));
+            queryClient.invalidateQueries(privilegeZonesKeys.tags());
+            queryClient.invalidateQueries(privilegeZonesKeys.tagDetail(tagId));
         },
     });
 };
 
 export const useAssetGroupTagInfo = (tagId: string) =>
     useQuery({
-        queryKey: zoneManagementKeys.tagDetail(tagId),
+        queryKey: privilegeZonesKeys.tagDetail(tagId),
         queryFn: async ({ signal }) => {
             const response = await apiClient.getAssetGroupTag(tagId, { signal });
             return response.data.data.tag;
@@ -307,7 +422,7 @@ export const useAssetGroupTags = () => {
     const queryEnabled = !isLoading && !isError && data?.enabled;
 
     return useQuery({
-        queryKey: zoneManagementKeys.tags(),
+        queryKey: privilegeZonesKeys.tags(),
         queryFn: getAssetGroupTags,
         enabled: queryEnabled,
     });
@@ -317,7 +432,7 @@ export const useOrderedTags = () => {
     const { isLoading, isError, data } = useAssetGroupTags();
 
     const orderedTags = (data ?? [])
-        ?.filter((tag) => tag.type === AssetGroupTagTypeTier)
+        ?.filter((tag) => tag.type === AssetGroupTagTypeZone)
         .sort((a, b) => {
             const aPos = a.position ?? 0;
             const bPos = b.position ?? 0;
@@ -345,7 +460,7 @@ export const useHighestPrivilegeTagId = () => {
 
 export const useLabels = () => {
     const tagsQuery = useAssetGroupTags();
-    const labelTypes: AssetGroupTagTypes[] = [AssetGroupTagTypeLabel, AssetGroupTagTypeOwned];
+    const labelTypes: AssetGroupTagType[] = [AssetGroupTagTypeLabel, AssetGroupTagTypeOwned];
 
     if (tagsQuery.isLoading || tagsQuery.isError) return [];
 
