@@ -709,6 +709,11 @@ export const allSections: Partial<Record<EntityKinds, (id: string) => EntityInfo
             label: 'Inbound Object Control',
             queryType: 'aiaca-inbound_object_control',
         },
+        {
+            id,
+            label: 'PKI Hierarchy',
+            queryType: 'aiaca-pki_hierarchy',
+        },
     ],
     [ActiveDirectoryNodeKind.CertTemplate]: (id: string) => [
         {
@@ -716,6 +721,11 @@ export const allSections: Partial<Record<EntityKinds, (id: string) => EntityInfo
             label: 'Inbound Object Control',
             queryType: 'certtemplate-inbound_object_control',
         },
+        {
+            id,
+            label: 'Published To CAs',
+            queryType: 'certtemplate-published_to_cas',
+        },
     ],
     [ActiveDirectoryNodeKind.Computer]: (id: string) => [
         {
@@ -843,6 +853,11 @@ export const allSections: Partial<Record<EntityKinds, (id: string) => EntityInfo
             label: 'Controllers',
             queryType: 'domain-controllers',
         },
+        {
+            id,
+            label: 'ADCS Escalations',
+            queryType: 'domain-adcs_escalations',
+        },
     ],
     [ActiveDirectoryNodeKind.EnterpriseCA]: (id: string) => [
         {
@@ -850,6 +865,16 @@ export const allSections: Partial<Record<EntityKinds, (id: string) => EntityInfo
             label: 'Inbound Object Control',
             queryType: 'enterpriseca-inbound_object_control',
         },
+        {
+            id,
+            label: 'PKI Hierarchy',
+            queryType: 'enterpriseca-pki_hierarchy',
+        },
+        {
+            id,
+            label: 'Published Templates',
+            queryType: 'enterpriseca-published_templates',
+        },
     ],
     [ActiveDirectoryNodeKind.GPO]: (id: string) => [
         {
@@ -943,6 +968,11 @@ export const allSections: Partial<Record<EntityKinds, (id: string) => EntityInfo
             label: 'Inbound Object Control',
             queryType: 'ntauthstore-inbound_object_control',
         },
+        {
+            id,
+            label: 'Trusted CAs',
+            queryType: 'ntauthstore-trusted_cas',
+        },
     ],
     [ActiveDirectoryNodeKind.OU]: (id: string) => [
         {
@@ -972,6 +1002,11 @@ export const allSections: Partial<Record<EntityKinds, (id: string) => EntityInfo
             label: 'Inbound Object Control',
             queryType: 'rootca-inbound_object_control',
         },
+        {
+            id,
+            label: 'PKI Hierarchy',
+            queryType: 'rootca-pki_hierarchy',
+        },
     ],
     [ActiveDirectoryNodeKind.IssuancePolicy]: (id: string) => [
         {
@@ -1607,10 +1642,16 @@ export const entityRelationshipEndpoints = {
             .then((res) => res.data),
     'aiaca-inbound_object_control': ({ id, skip, limit, type }) =>
         apiClient.getAIACAControllersV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
+    'aiaca-pki_hierarchy': ({ id, skip, limit, type }) =>
+        apiClient.getAIACAPKIHierarchyV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
     'certtemplate-inbound_object_control': ({ id, skip, limit, type }) =>
         apiClient
             .getCertTemplateControllersV2(id, skip, limit, type, { signal: controller.signal })
             .then((res) => res.data),
+    'certtemplate-published_to_cas': ({ id, skip, limit, type }) =>
+        apiClient
+            .getCertTemplatePublishedToCAsV2(id, skip, limit, type, { signal: controller.signal })
+            .then((res) => res.data),
     'computer-sessions': ({ id, skip, limit, type }) =>
         apiClient.getComputerSessionsV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
     'computer-local_admins': ({ id, skip, limit, type }) =>
@@ -1677,10 +1718,22 @@ export const entityRelationshipEndpoints = {
             .then((res) => res.data),
     'domain-controllers': ({ id, skip, limit, type }) =>
         apiClient.getDomainControllersV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
+    'domain-adcs_escalations': ({ id, skip, limit, type }) =>
+        apiClient
+            .getDomainADCSEscalationsV2(id, skip, limit, type, { signal: controller.signal })
+            .then((res) => res.data),
     'enterpriseca-inbound_object_control': ({ id, skip, limit, type }) =>
         apiClient
             .getEnterpriseCAControllersV2(id, skip, limit, type, { signal: controller.signal })
             .then((res) => res.data),
+    'enterpriseca-pki_hierarchy': ({ id, skip, limit, type }) =>
+        apiClient
+            .getEnterpriseCAPKIHierarchyV2(id, skip, limit, type, { signal: controller.signal })
+            .then((res) => res.data),
+    'enterpriseca-published_templates': ({ id, skip, limit, type }) =>
+        apiClient
+            .getEnterpriseCAPublishedTemplatesV2(id, skip, limit, type, { signal: controller.signal })
+            .then((res) => res.data),
     'gpo-ous': ({ id, skip, limit, type }) =>
         apiClient.getGPOOUsV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
     'gpo-computers': ({ id, skip, limit, type }) =>
@@ -1715,6 +1768,10 @@ export const entityRelationshipEndpoints = {
         apiClient
             .getNTAuthStoreControllersV2(id, skip, limit, type, { signal: controller.signal })
             .then((res) => res.data),
+    'ntauthstore-trusted_cas': ({ id, skip, limit, type }) =>
+        apiClient
+            .getNTAuthStoreTrustedCAsV2(id, skip, limit, type, { signal: controller.signal })
+            .then((res) => res.data),
     'ou-affecting_gpos': ({ id, skip, limit, type }) =>
         apiClient.getOUGPOsV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
     'ou-groups': ({ id, skip, limit, type }) =>
@@ -1725,6 +1782,8 @@ export const entityRelationshipEndpoints = {
         apiClient.getOUUsersV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
     'rootca-inbound_object_control': ({ id, skip, limit, type }) =>
         apiClient.getRootCAControllersV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
+    'rootca-pki_hierarchy': ({ id, skip, limit, type }) =>
+        apiClient.getRootCAPKIHierarchyV2(id, skip, limit, type, { signal: controller.signal }).then((res) => res.data),
     'issuancepolicy-inbound_object_control': ({ id, skip, limit, type }) =>
         apiClient
             .getIssuancePolicyControllersV2(id, skip, limit, type, { signal: controller.signal })
