@@ -14,7 +14,6 @@
 //
 // SPDX-License-Identifier: Apache-2.0
 
-export * from './abbreviatedNumber';
 export * from './api';
 export * from './array';
 export * from './colors';
@@ -25,13 +24,16 @@ export * from './datePicker';
 export * from './datetime';
 export * from './entityInfoDisplay';
 export * from './exportGraphData';
-export * from './finishedJobs';
 export * from './icons';
+export * from './jobs';
 export * from './luxon';
+export * from './numberFormatting';
+export * from './object';
 export * from './parseItemId';
 export * from './passwd';
 export * from './permissions';
 export * from './queries';
+export * from './quickUpload';
 export * from './searchParams';
 export * from './testHelpers';
 export * from './theme';
