@@ -14,16 +14,19 @@
 //
 // SPDX-License-Identifier: Apache-2.0
 
+import type { AxiosResponse } from 'axios';
 import {
     AssetGroupTag,
-    AssetGroupTagNode,
+    AssetGroupTagMember,
     AssetGroupTagSelector,
+    Client,
     CollectorManifest,
     CommunityCollectorType,
     CustomNodeKindType,
     EnterpriseCollectorType,
     GraphData,
     NodeSourceTypes,
+    ScheduledJobDisplay,
 } from './types';
 import { ConfigurationPayload } from './utils/config';
 
@@ -172,17 +175,23 @@ export type NewAuthToken = AuthToken & {
 
 export type CreateAuthTokenResponse = BasicResponse<NewAuthToken>;
 
-export type PreviewSelectorsResponse = BasicResponse<{ members: AssetGroupTagNode[] }>;
+export type PreviewSelectorsResponse = BasicResponse<{ members: AssetGroupTagMember[] }>;
 
-export interface AssetGroupTagMemberListItem extends AssetGroupTagNode {
+export interface AssetGroupTagMemberListItem extends AssetGroupTagMember {
     source: NodeSourceTypes;
 }
 
-export interface AssetGroupTagMemberInfo extends AssetGroupTagNode {
+export interface AssetGroupTagMemberInfo extends AssetGroupTagMember {
     properties: Record<string, any>;
     selectors: AssetGroupTagSelector[];
 }
 
+export type AssetGroupTagSearchResponse = BasicResponse<{
+    tags: AssetGroupTag[];
+    selectors: AssetGroupTagSelector[];
+    members: AssetGroupTagMember[];
+}>;
+
 export type AssetGroupTagResponse = BasicResponse<{ tag: AssetGroupTag }>;
 export type AssetGroupTagsResponse = BasicResponse<{ tags: AssetGroupTag[] }>;
 export type AssetGroupTagSelectorResponse = BasicResponse<{ selector: AssetGroupTagSelector }>;
@@ -234,10 +243,17 @@ export type AssetGroupMemberCountsResponse = BasicResponse<AssetGroupMemberCount
 export type SavedQuery = {
     id: number;
     name: string;
+    description: string;
     query: string;
     user_id: string;
 };
 
+export type SavedQueryPermissionsResponse = {
+    shared_to_user_ids: string[];
+    query_id: number | undefined;
+    public: boolean;
+};
+
 export type FileIngestJob = TimestampFields & {
     user_id: string;
     user_email_address: string;
@@ -247,6 +263,8 @@ export type FileIngestJob = TimestampFields & {
     end_time: string;
     last_ingest: string;
     id: number;
+    total_files: number;
+    failed_files: number;
 };
 
 export type ListFileIngestJobsResponse = PaginatedResponse<FileIngestJob[]>;
@@ -285,68 +303,8 @@ export type GetEnterpriseCollectorsResponse = BasicResponse<Record<EnterpriseCol
 
 export type GetCustomNodeKindsResponse = BasicResponse<CustomNodeKindType[]>;
 
-export type OuDetails = {
-    objectid: string;
-    name: string;
-    exists: boolean;
-    distinguishedname: string;
-    type: string;
-};
-
-export type DomainDetails = {
-    objectid: string;
-    name: string;
-    exists: boolean;
-    type: string;
-};
-
-export type DomainResult = {
-    job_id: number;
-    domain_name: string;
-    success: boolean;
-    message: string;
-    user_count: number;
-    group_count: number;
-    computer_count: number;
-    gpo_count: number;
-    ou_count: number;
-    container_count: number;
-    aiaca_count: number;
-    rootca_count: number;
-    enterpriseca_count: number;
-    ntauthstore_count: number;
-    certtemplate_count: number;
-    deleted_count: number;
-    id: number;
-    created_at: string;
-    updated_at: string;
-    deleted_at: {
-        Time: string;
-        Valid: boolean;
-    };
-};
-
-export type ScheduledJobDisplay = {
-    id: number;
-    client_id: string;
-    client_name: string;
-    event_id: number;
-    execution_time: string;
-    start_time: string;
-    end_time: string;
-    status: number;
-    status_message: string;
-    session_collection: boolean;
-    local_group_collection: boolean;
-    ad_structure_collection: boolean;
-    cert_services_collection: boolean;
-    ca_registry_collection: boolean;
-    dc_registry_collection: boolean;
-    all_trusted_domains: boolean;
-    domain_controller: string;
-    ous: OuDetails[];
-    domains: DomainDetails[];
-    domain_results: DomainResult[];
-};
-
 export type GetScheduledJobDisplayResponse = PaginatedResponse<ScheduledJobDisplay[]>;
+
+export type GetExportQueryResponse = AxiosResponse<Blob>;
+
+export type GetClientResponse = PaginatedResponse<Client[]>;
